@@ -10,10 +10,11 @@ use File::HomeDir;
 use Log::Any qw/$log/;
 use Path::Tiny qw/path rootdir cwd/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 our $pager;
 
-sub MSWin32 { $^O eq 'MSWin32' }
+sub DBVERSION { 1 }
+sub MSWin32   { $^O eq 'MSWin32' }
 
 has db => (
     is      => 'ro',
@@ -107,6 +108,8 @@ has user_dbw => (
     default => \&_build_user_dbw,
 );
 
+has work_buffer => ( is => 'rw', );
+
 sub BUILD {
     my $self = shift;
     my $opts = $self->opts;
@@ -119,11 +122,18 @@ sub BUILD {
 
     if ( $opts->{debug} ) {
         require Log::Any::Adapter;
-        Log::Any::Adapter->set('+App::bif::LAA');
+        if ( exists $INC{'Test/More.pm'} ) {
+
+            # Log::Any::Adapter::Diag can be found in t/lib/
+            Log::Any::Adapter->set('Diag');
+        }
+        else {
+            Log::Any::Adapter->set('+App::bif::LAA');
+        }
         $self->start_pager();
     }
 
-    $log->debugf( 'bif: %s %s', ref $self, $opts );
+    $log->infof( 'bif: %s %s', ref $self, $opts );
 
     return;
 }
@@ -208,9 +218,20 @@ sub _build_repo {
     return $repo;
 }
 
+sub dbfile {
+    my $self    = shift;
+    my $version = shift;
+    return sprintf( 'db-v%d.sqlite3', $version );
+}
+
 sub _build_user_db {
     my $self = shift;
-    my $dsn  = 'dbi:SQLite:dbname=' . $self->user_repo->child('db.sqlite3');
+    my $file = $self->user_repo->child( $self->dbfile( $self->DBVERSION ) );
+
+    return $self->err( 'DBNotFound', 'database not found: %s', $file )
+      unless -f $file;
+
+    my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DB;
     my $db =
@@ -224,7 +245,12 @@ sub _build_user_db {
 
 sub _build_user_dbw {
     my $self = shift;
-    my $dsn  = 'dbi:SQLite:dbname=' . $self->user_repo->child('db.sqlite3');
+    my $file = $self->user_repo->child( $self->dbfile( $self->DBVERSION ) );
+
+    return $self->err( 'DBNotFound', 'database not found: %s', $file )
+      unless -f $file;
+
+    my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DBW;
     my $dbw =
@@ -238,7 +264,12 @@ sub _build_user_dbw {
 
 sub _build_db {
     my $self = shift;
-    my $dsn  = 'dbi:SQLite:dbname=' . $self->repo->child('db.sqlite3');
+    my $file = $self->repo->child( $self->dbfile( $self->DBVERSION ) );
+
+    return $self->err( 'DBNotFound', 'database not found: %s', $file )
+      unless -f $file;
+
+    my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DB;
     my $db =
@@ -252,7 +283,12 @@ sub _build_db {
 
 sub _build_dbw {
     my $self = shift;
-    my $dsn  = 'dbi:SQLite:dbname=' . $self->repo->child('db.sqlite3');
+    my $file = $self->repo->child( $self->dbfile( $self->DBVERSION ) );
+
+    return $self->err( 'DBNotFound', 'database not found: %s', $file )
+      unless -f $file;
+
+    my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DBW;
     my $dbw =
@@ -266,6 +302,15 @@ sub _build_dbw {
 
 ### class methods ###
 
+sub new_cmd {
+    my $self  = shift;
+    my $class = shift;
+
+    Carp::croak($@) unless eval "require $class;";
+
+    return $class->new( %$self, @_ );
+}
+
 sub dispatch {
     my $self  = shift;
     my $class = shift;
@@ -358,6 +403,88 @@ sub header {
     ];
 }
 
+sub s2hms {
+    my $self = shift;
+    my $s    = shift;
+
+    return sprintf(
+        '%+0.2d:%0.2d:%0.2d',
+        int( $s / 3600 ),
+        int( ( $s - 3600 * int( $s / 3600 ) ) / 60 ),
+        $s % 60
+    );
+}
+
+sub s2hm {
+    my $self = shift;
+    my $s    = shift;
+
+    return sprintf( '%+0.2d:%0.2d',
+        int( $s / 3600 ),
+        int( $s - 3600 * int( $s / 3600 ) ) / 60 );
+}
+
+sub datetime2s {
+    my $self   = shift;
+    my $dt     = shift;
+    my $new_dt = $dt;
+
+    if ( $dt =~ m/^(\d?\d):(\d{2})$/ ) {
+        my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
+          localtime(time);
+
+        $new_dt = sprintf(
+            '%0.4d-%0.2d-%0.2d %0.2d:%0.2d:%0.2d',
+            $year + 1900,
+            $mon + 1, $mday, $1, $2, 0
+        );
+    }
+    elsif ( $dt =~ m/^(\d{2}):(\d{2}):(\d{2})$/ ) {
+        my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
+          localtime(time);
+
+        $new_dt = sprintf(
+            '%0.4d-%0.2d-%0.2d %0.2d:%0.2d:%0.2d',
+            $year + 1900,
+            $mon + 1, $mday, $1, $2, $3
+        );
+    }
+    elsif ( $dt =~ m/^yesterday (\d?\d):(\d{2})$/ ) {
+        my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
+          localtime( time - 24 * 60 * 60 );
+
+        $new_dt = sprintf(
+            '%0.4d-%0.2d-%0.2d %0.2d:%0.2d:%0.2d',
+            $year + 1900,
+            $mon + 1, $mday, $1, $2, 0
+        );
+    }
+    elsif ( $dt =~ m/^yesterday (\d?\d):(\d{2}):(\d{2})$/ ) {
+        my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
+          localtime( time - 24 * 60 * 60 );
+
+        $new_dt = sprintf(
+            '%0.4d-%0.2d-%0.2d %0.2d:%0.2d:%0.2d',
+            $year + 1900,
+            $mon + 1, $mday, $1, $2, $3
+        );
+    }
+    elsif ( $dt =~ m/^(\d{4})-(\d{2})-(\d{2})$/ ) {
+        $new_dt .= $dt . ' 00:00:00';
+    }
+    elsif ( $dt =~ m/^(\d{4})-(\d{2})-(\d{2}) (\d?\d):(\d{2})$/ ) {
+        $new_dt = $dt . ':00';
+    }
+
+    $log->debugf( 'datetime2s "%s" -> "%s"', $dt, $new_dt );
+    if ( $new_dt =~ m/^(\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2}):(\d{2})$/ ) {
+        require Time::Local;
+        return Time::Local::timelocal( $6, $5, $4, $3, $2 - 1, $1 - 1900 );
+    }
+
+    return $self->err( 'InvalidDateTime', 'invalid date/time string: %s', $dt );
+}
+
 sub ctime_ago {
     my $self = shift;
     my $row  = shift;
@@ -457,7 +584,7 @@ sub user_id {
 
 sub uuid2id {
     my $self = shift;
-    my $try  = shift // Carp::croak 'uuid2id needs defined';
+    my $try  = shift // Carp::confess 'uuid2id needs defined';
     my $opts = $self->opts;
     Carp::croak 'usage' if @_;
 
@@ -477,37 +604,19 @@ sub uuid2id {
 
 sub get_project {
     my $self = shift;
-    my $path = shift;
+    my $path = shift // Carp::confess 'path must be defined';
     my $db   = $self->db;
 
-    my $hub;
-    if ( $path =~ m/(.*?)\/(.*)/ ) {
-        $hub  = $1;
-        $path = $2;
-    }
+    my @matches = $db->get_projects($path);
 
-    my @matches = $db->get_projects( $path, $hub );
+    return $self->err( 'ProjectNotFound', "project not found: $path" )
+      unless @matches;
 
-    if ( 0 == @matches ) {
-        return $self->err( 'ProjectNotFound', "project not found: $path" )
-          unless $hub;
-
-        return $self->err( 'ProjectNotFound', "project not found: $path\@$hub" )
-          if eval { $self->get_hub($hub) };
-
-        return $self->err( 'HubNotFound',
-            "hub not found: $hub (for $path\@$hub)" );
-    }
-    elsif ( 1 == @matches ) {
-        return $matches[0];
-    }
-    elsif ( not defined $matches[0]->{hub_name} ) {
-        return $matches[0];
-    }
+    return $matches[0] if 1 == @matches;
 
     return $self->err( 'AmbiguousPath',
         "ambiguous path \"$path\" matches the following:\n" . '    '
-          . join( "\n    ", map { "$path\@$_->{hub_name}" } @matches ) );
+          . join( "\n    ", map { "$_->{path}" } @matches ) );
 }
 
 sub get_hub {
@@ -515,18 +624,34 @@ sub get_hub {
     my $name = shift;
     my $db   = $self->db;
 
+    if ( $name =~ m/^(\d+)$/ ) {
+        return $db->xhashref(
+            select     => [qw/h.id p.name t.kind t.uuid t.first_change_id/],
+            from       => 'hubs h',
+            inner_join => 'projects p',
+            on         => 'p.id = h.id',
+            inner_join => 'topics t',
+            on         => 't.id = h.id',
+            where      => { 'h.id' => $name },
+        );
+    }
+
     my ($hub) = $db->xhashref(
-        select           => [qw/h.id h.name t.kind t.uuid t.first_change_id/],
+        select           => [qw/h.id p.name t.kind t.uuid t.first_change_id/],
         from             => 'hubs h',
+        inner_join       => 'projects p',
+        on               => 'p.id = h.id',
         inner_join       => 'topics t',
         on               => 't.id = h.id',
-        where            => { 'h.name' => $self->uuid2id($name) },
-        union_all_select => [qw/h.id h.name t.kind t.uuid t.first_change_id/],
+        where            => { 'p.name' => $self->uuid2id($name) },
+        union_all_select => [qw/h.id p.name t.kind t.uuid t.first_change_id/],
         from             => 'hub_repos hr',
         inner_join       => 'hubs h',
         on               => 'h.id = hr.hub_id',
         inner_join       => 'topics t',
         on               => 't.id = h.id',
+        inner_join       => 'projects p',
+        on               => 'p.id = h.id',
         where            => { 'hr.location' => $name },
     );
 
@@ -584,6 +709,8 @@ sub prompt_edit {
 #
 ";
 
+    my $now = time;
+
     foreach my $key ( sort keys %{ $args{opts} } ) {
         next if $key =~ m/^_/;
         next unless defined $args{opts}->{$key};
@@ -630,7 +757,8 @@ sub get_change {
     my $token           = shift // Carp::croak('get_change needs defined');
     my $first_change_id = shift;
 
-    return $self->err( 'ChangeNotFound', "change not found: $token" )
+    return $self->err( 'InvalidChangeID',
+        "invalid change ID (must be cID): $token" )
       unless $token =~ m/^c(\d+)$/;
 
     my $id = $1;
@@ -680,25 +808,9 @@ sub get_topic {
                 't.kind AS kind',
                 't.uuid AS uuid',
                 't.first_change_id AS first_change_id',
-                qv(undef)->as('project_issue_id'),
-                qv(undef)->as('project_id'),
             ],
             from  => 'topics t',
-            where => [ 't.id = ', qv($token), ' AND t.kind != ', qv('issue') ],
-            union_all_select => [
-                't.id AS id',
-                't.kind AS kind',
-                't.uuid AS uuid',
-                't.first_change_id AS first_change_id',
-                'pi.id AS project_issue_id',
-                'pi.project_id',
-            ],
-            from       => 'project_issues pi',
-            inner_join => 'topics t',
-            on         => 't.id = pi.issue_id',
-            where      => { 'pi.id' => $token },
-            order_by   => 'project_issue_id DESC',
-            limit      => 1,
+            where => { 't.id' => $token },
         );
 
         return $self->err( 'WrongKind', 'topic (%s) is not a %s: %d',
@@ -716,31 +828,208 @@ sub get_topic {
     return $self->err( 'TopicNotFound', "$kind not found: $token" );
 }
 
+sub current_work {
+    my $self = shift;
+    return $self->dbw->xhashref(
+        select => [
+            't.id AS id',
+            't.kind AS kind',
+            'tp.path AS path',
+            'wb.start AS start',
+            'wb.billable AS billable',
+        ],
+        from       => 'work_buffers wb',
+        inner_join => 'topics t',
+        on         => 't.id = wb.topic_id',
+        inner_join => 'topic_path tp',
+        on         => 'tp.id = t.id',
+        where      => { 'wb.stop' => undef },
+    );
+}
+
+sub start_work {
+    my $self = shift;
+    my $args = {@_};
+    my $dbw  = $self->dbw;
+
+    if ( $args->{save} ) {
+        my $ref = $dbw->xhashref(
+            select => '*',
+            from   => 'work_buffers',
+            where  => { stop => undef },
+        );
+
+        if ($ref) {
+            $self->stop_work( stop => $args->{start} );
+            $self->work_buffer($ref);
+        }
+    }
+
+    return $self->dbw->xdo(
+        insert_into => 'work_buffers',
+        values      => {
+            topic_id      => $args->{id},
+            start         => $args->{start},
+            start_comment => $args->{start_comment},
+            stop          => $args->{stop},
+            stop_comment  => $args->{stop_comment},
+            billable      => $args->{billable},
+        },
+    );
+}
+
+sub stop_work {
+    my $self = shift;
+    my $args = {@_};
+    my $dbw  = $self->dbw;
+
+    $dbw->xdo(
+        update => 'work_buffers',
+        set    => {
+            stop         => $args->{stop},
+            stop_comment => $args->{stop_comment},
+        },
+        where => { stop => undef },
+    );
+
+    if ( $args->{restore} and my $ref = $self->work_buffer ) {
+
+        $self->start_work(
+            id            => $ref->{topic_id},
+            start         => $args->{stop},
+            start_comment => $ref->{start_comment},
+            billable      => $ref->{billable},
+        );
+
+        $self->work_buffer(undef);
+    }
+}
+
 sub new_change {
     my $self = shift;
     my %vals = @_;
+    my $dbw  = $self->dbw;
 
-    my $dbw    = $self->dbw;
-    my $id     = ( delete $vals{id} ) // $dbw->nextval('changes');
-    my $author = delete $vals{author};
-    my $email  = delete $vals{email};
+    $vals{id} ||= $dbw->nextval('changes');
+    my ( $author, $author_contact, $author_contact_method, $author_shortname )
+      = $dbw->xlist(
+        select     => [qw/e.name ecm.mvalue ecm.method i.shortname/],
+        from       => 'bifkv b',
+        inner_join => 'entities e',
+        on         => 'e.id = b.identity_id',
+        inner_join => 'identities i',
+        on         => 'i.id = b.identity_id',
+        inner_join => 'entity_contact_methods ecm',
+        on         => 'ecm.id = e.default_contact_method_id',
+        where      => { key => 'self' },
+      );
+    $vals{author}                //= $author;
+    $vals{author_contact}        //= $author_contact;
+    $vals{author_contact_method} //= $author_contact_method;
+    $vals{author_shortname}      //= $author_shortname;
 
-    state $have_dbix = DBIx::ThinSQL->import(qw/ qv coalesce /);
+    return $self->err( 'NoSelfIdentity',
+        'no "self" identity defined at change begin' )
+      unless $vals{author};
 
-    my $res = $dbw->xdo(
-        insert_into => [ 'changes', 'id', 'identity_id', sort keys %vals ],
-        select      => [
-            qv($id), 'bif.identity_id',
-            map { qv( $vals{$_} ) } sort keys %vals
-        ],
-        from  => 'bifkv bif',
-        where => { 'bif.key' => 'self' },
+    $dbw->xdo(
+        insert_into => 'func_begin_change',
+        values      => \%vals,
+    );
+
+    return $vals{id};
+}
+
+sub check {
+    my $self = shift;
+    my $id   = shift;
+    my $db   = shift || $self->db;
+
+    state $have_changeset = require Bif::DB::Plugin::ChangeUUIDv1;
+    state $have_yaml      = require YAML::Tiny;
+    state $have_encode    = require Encode;
+    state $have_digest    = require Digest::SHA;
+
+    my $changeset =
+      $db->uchangeset_v1($id) || Carp::croak "invalid change.id: $id";
+
+    my $begin = shift @$changeset;
+    my $end   = pop @$changeset;
+    my $uuid  = delete $end->{uuid};
+    my $short = substr( $uuid, 0, 8 );
+
+    foreach my $x (@$changeset) {
+        next
+          unless ref $x eq 'HASH'
+          && exists $x->{_delta}
+          && $x->{_delta} =~ m/^new_/;
+
+        delete $x->{uuid};
+    }
+
+    my $yaml = YAML::Tiny::Dump( [ $begin, @$changeset, $end ] );
+    my $sha1 = Digest::SHA::sha1_hex( Encode::encode( 'UTF-8', $yaml ) );
+
+    my $action = $db->xval(
+        select => ['c.action'],
+        from   => 'changes c',
+        where  => { 'c.id' => $id },
+    );
+
+    my ( $red, $reset ) = $self->colours( 'red', 'reset' );
+    return ( 1, "[change: $id <$short>] $action" ) if $uuid eq $sha1;
+    return ( 0, "[change: $id <$short>] $action ${red}INVALID$reset" );
+}
+
+sub end_change {
+    my $self = shift;
+    my $dbw  = $self->dbw;
+    my %args = @_;
+
+    my $iid = $dbw->xval(
+        select => [ 'bif.identity_id', ],
+        from   => 'bifkv bif',
+        where  => { 'bif.key' => 'self' },
     );
 
     return $self->err( 'NoSelfIdentity',
-        'no "self" identity ' . join( ' ', caller ) )
-      unless $res > 0;
-    return $id;
+        'no "self" identity defined at change end' )
+      unless $iid;
+
+    $dbw->xdo(
+        insert_into => 'func_end_change',
+        values      => {
+            identity_id => $iid,
+            %args,
+        },
+    );
+
+    $dbw->xdo(
+        insert_into => 'func_merge_changes',
+        values      => { merge => 1 },
+    );
+
+    my $change_id = $dbw->xval( select => 'currval("changes")' );
+    my ( $ok, $str ) = $self->check( $change_id, $dbw );
+    return print $str. "\n" if $ok;
+
+    # Show the diff to see what's wrong
+    $self->new_cmd(
+        'App::bif::show::change',
+        db   => $self->dbw,    # to make current txn visible
+        opts => {
+            uid  => 'c' . $change_id,
+            diff => 1,
+        }
+    )->run;
+
+    my $keep_invalid = $dbw->xval(
+        select => 'bool_val',
+        from   => 'bifkv',
+        where  => { key => 'keep_invalid' },
+    );
+    return $self->err( 'InvalidUUID', $str ) unless $keep_invalid;
+    return print $str;
 }
 
 sub DESTROY {
@@ -773,7 +1062,9 @@ sub new {
 
 sub as_string {
     my $self = shift;
-    return $self->{_bif_ok_msg} || ref $self;
+    return $self->{_bif_ok_msg}
+      if $self->{_bif_ok_msg} && !ref $self->{_bif_ok_msg};
+    return ref $self;
 }
 
 package Bif::Error;
@@ -795,7 +1086,7 @@ App::bif - A base class for App::bif::* commands
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -957,6 +1248,11 @@ You should manually import any L<DBIx::ThinSQL> functions you need only
 after calling C<$self->dbw>, in order to keep startup time short for
 cases such as when the repository is not found.
 
+=item new_cmd($class, %attrs)
+
+Loads C<$class> and creates a new object from that class populated with
+the attributes from C<$self> plus the attributes in the C<%attrs> HASH.
+
 =item dispatch($class, $attrs)
 
 Loads the bif class C<$class>, creates a new object populated with the
@@ -1045,14 +1341,57 @@ reference containg the following keys:
 
 =back
 
-If the found topic is an issue then the following keys will also
-contain valid values:
+=item current_work -> HashRef
+
+Returns a hashref representing the currently open work buffer:
 
 =over
 
-=item * project_issue_id - the project-specific topic ID
+=item * id
 
-=item * project_id - the project ID matching the project_issue_id
+=item * kind
+
+=item * path
+
+=item * start
+
+=item * billable
+
+=back
+
+=item start_work(%opts)
+
+Creates a new entry in the work_buffers table.
+
+=over
+
+=item * id
+
+=item * start
+
+=item * start_comment
+
+=item * stop
+
+=item * stop_comment
+
+=item * billable
+
+=item * restore
+
+=back
+
+=item stop_work(%opts)
+
+Finalizes an open entry in the work_buffers table.
+
+=over
+
+=item * stop
+
+=item * stop_comment
+
+=item * save
 
 =back
 
@@ -1062,6 +1401,53 @@ Creates a new row in the changes table according to the content of
 C<%args> (must include at least a C<message> value) and the current
 context (identity). Returns the integer ID of the change.
 
+=item check( $id ) -> (Bool,Str)
+
+Computes the uuid of the change $id and compares it against the stored
+uuid value. Returns two variables: the first is a true/false scalar
+indicating validity, and the second is a human-readable status string.
+
+A valid uuid example:
+
+    [u.a83372c(.11)] some action string
+
+An invalid uuid example:
+
+    [u.328ea8b(.12)] another action string INVALID
+
+=item s2hms($seconds) -> '+hh:mm:ss'
+
+Converts the integer C<$seconds> into a string representing the hours,
+minutes and seconds that make up the delta.
+
+=item s2hm($seconds) -> '+hh:mm'
+
+Converts the integer C<$seconds> into a string representing the hours
+and minutes that make up the delta.
+
+=item datetime2s($str) -> $epoch
+
+Converts a partial date/time string into a UNIX epoch, with certain
+assumptions as to the date. Accepts the following variations:
+
+=over
+
+=item * [h]h:mm
+
+=item * [h]h:mm:ss
+
+=item * yesterday [h]h:mm
+
+=item * yesterday [h]h:mm:ss
+
+=item * yyyy-mm-dd
+
+=item * yyyy-mm-dd [h]h:mm
+
+=item * yyyy-mm-dd [h]h:mm:ss
+
+=back
+
 =back
 
 =head1 SEE ALSO
@@ -1074,7 +1460,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
