@@ -1,9 +1,9 @@
 package App::bif::Build;
 use strict;
 use warnings;
-$App::bif::Build::VERSION = '0.1.4';
-$App::bif::Build::COMMIT = 'd229ca1cf888a3666e406c210da0105a06ab3928';
-$App::bif::Build::DATE = '2014-10-27 08:20:37';
+$App::bif::Build::VERSION = '0.1.5_1';
+$App::bif::Build::COMMIT = '6fcaf2588a0cfab0d72c114360b95d48a1f33a18';
+$App::bif::Build::DATE = '2015-06-26 08:08:47';
 $App::bif::Build::FILE = __FILE__;
 1;
 __END__
@@ -14,7 +14,7 @@ App::bif::Build - build-time constants for App-bif
 
 =head1 VERSION
 
-0.1.0_28 (2014-10-27)
+0.1.0_28 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -40,12 +40,12 @@ were set as follows:
 
 =over
 
-=item $App::bif::Build::COMMIT = "d229ca1cf888a3666e406c210da0105a06ab3928"
+=item $App::bif::Build::COMMIT = "6fcaf2588a0cfab0d72c114360b95d48a1f33a18"
 
 The Git commit hash at the head of the branch when the App-bif
 distribution was created.
 
-=item $App::bif::Build::DATE = "2014-10-27 08:20:37"
+=item $App::bif::Build::DATE = "2015-06-26 08:08:47"
 
 The UTC date that the Makefile.PL file was run.
 
@@ -54,7 +54,7 @@ The UTC date that the Makefile.PL file was run.
 The installation location of this module, which cannot be
 documented here as it is only known at runtime.
 
-=item $App::bif::Build::VERSION = "0.1.4"
+=item $App::bif::Build::VERSION = "0.1.5_1"
 
 The version of the App-bif distribution.
 
@@ -70,7 +70,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
