@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use parent 'Log::Any::Adapter::FileScreenBase';
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 
 __PACKAGE__->make_logging_methods(
     sub {
@@ -23,7 +23,7 @@ App::bif::LAA - Simple adapter for logging to current filehandle
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
