@@ -1,6 +1,6 @@
 package App::bif::OptArgs;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 
 package    # do a little hiding
   App::bif;
@@ -85,6 +85,12 @@ arg name => (
     comment => 'name of new hub',
 );
 
+opt keep_invalid => (
+    isa     => 'Bool',
+    comment => 'Keep invalid updates in the database',
+    hidden  => 1,
+);
+
 arg location => (
     isa     => 'Str',
     comment => 'location of new remote hub',
@@ -180,7 +186,12 @@ subcmd(
 
 arg name => (
     isa     => 'Str',
-    comment => 'name of your organisation\'s hub',
+    comment => 'name of organisation\'s hub',
+);
+
+arg title => (
+    isa     => 'Str',
+    comment => 'title of organisation\'s hub',
 );
 
 arg locations => (
@@ -359,20 +370,6 @@ arg items => (
     required => 1,
 );
 
-# ------------------------------------------------------------------------
-# bif list repo
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/list actions/],
-    comment => 'list actions in the current repository',
-);
-
-opt action => (
-    isa     => 'Bool',
-    alias   => 'a',
-    comment => 'order actions by action ID instead of time'
-);
-
 # ------------------------------------------------------------------------
 # bif list entities
 # ------------------------------------------------------------------------
@@ -456,7 +453,7 @@ subcmd(
 );
 
 opt status => (
-    isa     => 'Str',
+    isa     => 'ArrayRef',
     alias   => 's',
     comment => 'limit topics to a specific status',
 );
@@ -515,6 +512,15 @@ subcmd(
     comment => 'list registered providers',
 );
 
+# ------------------------------------------------------------------------
+# list tables
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/list tables/],
+    hidden  => 1,
+    comment => 'list database tables',
+);
+
 # ------------------------------------------------------------------------
 # bif list tasks
 # ------------------------------------------------------------------------
@@ -692,6 +698,49 @@ arg id => (
     required => 1,
 );
 
+# ------------------------------------------------------------------------
+# bif show timesheet
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/show timesheet/],
+    comment => 'display time worked per project',
+);
+
+arg date => (
+    isa     => 'Str',
+    comment => 'timesheet start date',
+);
+
+opt number => (
+    isa     => 'Int',
+    alias   => 'n',
+    comment => 'number of timespans to generate',
+);
+
+opt day => (
+    isa     => 'Bool',
+    alias   => 'd',
+    comment => 'generate a daily timesheet',
+);
+
+opt week => (
+    isa     => 'Bool',
+    alias   => 'w',
+    comment => 'generate a weekly timesheet',
+);
+
+opt month => (
+    isa     => 'Bool',
+    alias   => 'm',
+    comment => 'generate a monthly timesheet',
+);
+
+opt year => (
+    isa     => 'Bool',
+    alias   => 'y',
+    comment => 'generate a yearly timesheet',
+);
+
 # ------------------------------------------------------------------------
 # bif show change
 # ------------------------------------------------------------------------
@@ -706,6 +755,20 @@ arg uid => (
     comment  => 'the change cID',
 );
 
+opt diff => (
+    isa     => 'Bool',
+    alias   => 'd',
+    comment => 'diff actual/expected values (devel only)',
+);
+
+# ------------------------------------------------------------------------
+# bif show version
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/show version/],
+    comment => 'show version and build informationL',
+);
+
 # ------------------------------------------------------------------------
 # bif log
 # ------------------------------------------------------------------------
@@ -730,6 +793,26 @@ opt uuid => (
     comment => 'treat arguments as if they are a UUIDs',
 );
 
+opt format => (
+    isa     => 'Str',
+    alias   => 'f',
+    default => 'full',
+    comment => 'output format: full | short | custom:...',
+);
+
+opt order => (
+    isa     => 'Str',
+    alias   => 'o',
+    default => 'time',
+    comment => 'output order: time | id | custom:...',
+);
+
+opt short => (
+    isa     => 'Bool',
+    alias   => 's',
+    comment => 'equivalent to "--format short"',
+);
+
 # ------------------------------------------------------------------------
 # bif log identity
 # ------------------------------------------------------------------------
@@ -869,6 +952,12 @@ opt reply => (
     alias   => 'r',
 );
 
+opt title => (
+    isa     => 'Str',
+    alias   => 't',
+    comment => 'Title'
+);
+
 # ------------------------------------------------------------------------
 # bif update identity
 # ------------------------------------------------------------------------
@@ -917,6 +1006,18 @@ arg id => (
     comment  => 'hub ID',
 );
 
+opt name => (
+    isa     => 'Str',
+    alias   => 'n',
+    comment => 'hub name'
+);
+
+opt title => (
+    isa     => 'Str',
+    alias   => 't',
+    comment => 'hub title'
+);
+
 # ------------------------------------------------------------------------
 # bif update issue
 # ------------------------------------------------------------------------
@@ -1355,6 +1456,12 @@ arg directory => (
     comment => 'location if this is a hub upgrade',
 );
 
+opt force => (
+    isa     => 'Bool',
+    alias   => 'f',
+    comment => 'force an upgrade, even if to same version',
+);
+
 # ------------------------------------------------------------------------
 # bif sql
 # ------------------------------------------------------------------------
@@ -1376,12 +1483,79 @@ opt noprint => (
     alias   => 'n',
 );
 
+opt test => (
+    isa     => 'Bool',
+    comment => 'use Test::More::diag to output rows',
+    alias   => 't',
+);
+
 opt write => (
     isa     => 'Bool',
     comment => 'run with a writeable database (default is read-only)',
     alias   => 'w',
 );
 
+# ------------------------------------------------------------------------
+# wlog
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/wlog/],
+    comment => 'review entries in the work buffer',
+);
+
+opt long => (
+    isa     => 'Bool',
+    alias   => 'l',
+    comment => 'print multiple-line email-style work entries',
+);
+
+# ------------------------------------------------------------------------
+# bif work
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/work/],
+    comment => 'work on a topic',
+);
+
+arg id => (
+    isa     => 'Str',
+    comment => 'topic ID or PATH to work on',
+);
+
+arg comment => (
+    isa     => 'Str',
+    greedy  => 1,
+    comment => 'comment to record with this work',
+);
+
+opt at => (
+    isa     => 'Str',
+    alias   => 'a',
+    default => sub {
+        my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
+          localtime(time);
+        return sprintf(
+            '%0.4d-%0.2d-%0.2d %0.2d:%0.2d:%0.2d',
+            $year + 1900,
+            $mon + 1, $mday, $hour, $min, $sec
+        );
+    },
+    comment => 'start or stop time: [yyyy-mm-dd] hh:mm',
+);
+
+opt force => (
+    isa     => 'Bool',
+    alias   => 'f',
+    comment => 'force work when working something else',
+);
+
+opt not_billable => (
+    isa     => 'Bool',
+    alias   => 'B',
+    default => 0,
+    comment => 'do not record this work on next update',
+);
+
 1;
 __END__
 
@@ -1394,7 +1568,7 @@ App::bif::OptArgs - bif command argument & option definitions
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -1416,7 +1590,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
