@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -21,28 +21,20 @@ sub run {
 
     $dbw->txn(
         sub {
-            $self->new_change(
-                action  => "drop issue $info->{id} <$uuid>",
-                message => "    [  Dropped Issue:        ]\n"
-                  . "    [    ID: $info->{id}  ]",
-            );
+            $opts->{change_id} = $self->new_change;
 
-            my $res = $dbw->xdo(
+            $dbw->xdo(
                 delete_from => 'issues',
                 where       => { id => $info->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
+            $self->end_change(
+                id            => $opts->{change_id},
+                action_format => "drop issue $info->{id} <$uuid>",
+                message       => "    [  Dropped Issue:        ]\n"
+                  . "    [    ID: $info->{id}  ]",
             );
 
-            if ($res) {
-                print "Dropped issue: $opts->{id} <$uuid>\n";
-            }
-            else {
-                $self->err( 'NothingDropped', 'nothing dropped!' );
-            }
         }
     );
 
@@ -60,7 +52,7 @@ bif-drop-issue - remove an issue from the repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -101,7 +93,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
