@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -18,47 +18,36 @@ sub run {
         return $self->ok('DropNoForce');
     }
 
-    my $uuid = substr( $info->{uuid}, 0, 8 );
-
     $dbw->txn(
         sub {
-            my $path =
-              $info->{hub_id}
-              ? "$info->{path}\@$info->{hub_name}"
-              : $info->{path};
-
-            $self->new_change(
-                action  => "drop project $path",
-                message => "    [  Dropped Project:        ]\n"
-                  . "    [    Path: $path  ]",
-            );
-
-            my $res;
+            $opts->{change_id} = $self->new_change;
 
             if ( $info->{hub_id} ) {
-                $res = $self->drop_shallow($info);
+                $self->drop_shallow($info);
+
+                $self->end_change(
+                    id            => $opts->{change_id},
+                    action_format => "drop project $info->{path} (shallow)",
+                    message       => "    [  Dropped Project:        ]\n"
+                      . "    [    Path: $info->{path}  ]\n\n"
+                      . "(shallow drop - project still exists on hub\n"
+                      . " and shared issues will remain)\n",
+                );
             }
             else {
-                $res = $dbw->xdo(
+                $dbw->xdo(
                     delete_from => 'projects',
                     where       => { id => $info->{id} },
                 );
+
+                $self->end_change(
+                    id            => $opts->{change_id},
+                    action_format => "drop project $info->{path}",
+                    message       => "    [  Dropped Project:        ]\n"
+                      . "    [    Path: $info->{path}  ]\n",
+                );
             }
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
-            );
-
-            if ($res) {
-                print "Dropped project: $path <$uuid>\n";
-                print "(shallow drop - project still exists on hub"
-                  . " and shared issues will remain)\n"
-                  if $info->{hub_id};
-            }
-            else {
-                $self->err( 'NothingDropped', 'nothing dropped!' );
-            }
         }
     );
 
@@ -73,24 +62,26 @@ sub drop_shallow {
 
     # Drop issues that are not part of any other project
     my $res = $dbw->xdo(
+        with => 'x',
+        as   => sq(
+            select    => [ 'i.id', 'COUNT(i2.id) AS total' ],
+            from      => 'issues i',
+            left_join => 'issues i2',
+            on        => 'i2.src_id = i.id',
+            where     => {
+                'i.project_id' => $info->{id},
+                'i.src_id'     => undef,
+            },
+            group_by => 'i.id',
+            having   => 'total = 0',
+        ),
         delete_from => 'issues',
         where       => [
             'id IN ',
             sq(
-                select => 'x.issue_id',
-                from   => sq(
-                    select =>
-                      [ 'pi.issue_id', 'COUNT(pi2.project_id) AS total' ],
-                    from       => 'project_issues pi',
-                    inner_join => 'project_issues pi2',
-                    on         => 'pi2.issue_id = pi.issue_id',
-                    where      => {
-                        'pi.project_id' => $info->{id},
-                    },
-                    group_by => 'pi.issue_id',
-                    having   => 'total = 1',
-                )->as('x'),
-            ),
+                select => 'x.id',
+                from   => 'x',
+            )
         ],
     );
 
@@ -152,7 +143,7 @@ bif-drop-project - remove an project from the repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -193,7 +184,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
