@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Path::Tiny qw/cwd path/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -28,7 +28,17 @@ sub run {
             subref => sub {
 
                 # This $self is a new_repo with a valid db handle
-                my $self = shift;
+                my $self          = shift;
+                my $major_version = shift;
+                my $minor_version = shift;
+
+                $self->dbw->xdo(
+                    insert_into => 'bifkv',
+                    values      => {
+                        key      => 'keep_invalid',
+                        bool_val => $opts->{keep_invalid},
+                    },
+                );
 
                 $self->dispatch(
                     'App::bif::new::identity',
@@ -39,6 +49,12 @@ sub run {
                         },
                     }
                 );
+
+   #                $self->end_change(
+   #                    id            => $self->new_change,
+   #                    action_format => "init",
+   #                    message => "Initialized v$major_version.$minor_version",
+   #                );
             },
         }
     ) if !-d $user_repo;
@@ -50,22 +66,42 @@ sub run {
             subref => sub {
 
                 # This $self is a new_repo with a valid db handle
-                my $self = shift;
+                my $self          = shift;
+                my $major_version = shift;
+                my $minor_version = shift;
+
+                $self->dbw->xdo(
+                    insert_into => 'bifkv',
+                    values      => {
+                        key      => 'keep_invalid',
+                        bool_val => $opts->{keep_invalid},
+                    },
+                );
+
                 $self->dispatch(
                     'App::bif::pull::identity',
                     {
                         opts => {
+                            %$opts,    # for global options
                             location => $user_repo,
                             self     => 1,
                         },
                     },
                 );
 
+   #                $self->end_change(
+   #                    id            => $self->new_change,
+   #                    action_format => "init",
+   #                    message => "Initialized v$major_version.$minor_version",
+   #                );
+
                 $self->dispatch(
                     'App::bif::new::hub',
                     {
                         opts => {
+                            %$opts,    # for global options
                             name      => $opts->{name},
+                            title     => $opts->{name},
                             locations => [ $opts->{location} || $dir ],
                             default   => 1,
                         },
@@ -89,7 +125,7 @@ bif-init - initialize a new bif repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -236,6 +272,13 @@ The name of a new hub repository
 
 The location of a new I<remote> hub repository.
 
+=item --keep-invalid
+
+This sets the C<keep_invalid> option in the C<bifkv> table to true.
+This prevents invalid changes from being rolled back out of the
+database so they can be inspected. As this option is aimed at
+developers it is hidden from normal usage messages.
+
 =back
 
 Note that the global C<--user-repo> option does not apply in the
@@ -271,7 +314,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
