@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Term::ANSIColor qw/color/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -16,23 +16,21 @@ sub run {
 
     my $data = $db->xarrayrefs(
         select => [
-            concat( qv( color('yellow') ), 't.kind', qv( color('reset') ) )
-              ->as('type'),
-            'h.id',
-            'COALESCE(h.name,"") AS hname',
+            qw/t.kind h.id p.path/,
             'COALESCE(hr.location,"") AS location',
-            'COUNT(p.id)',
+            'COUNT(p.id) AS project_count',
         ],
         from       => 'hubs h',
+        inner_join => 'projects p',
+        on         => 'p.id = h.id',
         inner_join => 'topics t',
         on         => 't.id = h.id',
         left_join  => 'hub_repos hr',
         on         => 'hr.id = h.default_repo_id',
-        left_join  => 'projects p',
-        on         => 'p.hub_id = h.id',
-        group_by =>
-          [ 'h.id', 'COALESCE(h.name,"")', 'COALESCE(hr.location,"")', ],
-        order_by => 'hname',
+        left_join  => 'projects p2',
+        on         => 'p2.hub_id = h.id',
+        group_by   => [qw/t.kind h.id p.name location/],
+        order_by   => 'p.name',
     );
 
     return $self->ok('ListHubs') unless $data;
@@ -56,7 +54,7 @@ bif-list-hubs - list hubs registered with current repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -76,7 +74,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
