@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -34,28 +34,22 @@ sub run {
     foreach my $project (@projects) {
 
         my $data = $db->xarrayrefs(
-            select => [
-                'project_issues.id AS id',
-                'issues.title AS title',
-                'issue_status.status',
-            ],
-            from       => 'issue_status',
-            inner_join => 'project_issues',
-            on         => 'project_issues.issue_status_id = issue_status.id',
-            inner_join => 'issues',
-            on         => 'issues.id = project_issues.issue_id',
-            where      => {
-                'issue_status.project_id' => $project->[0],
+            select     => [ 'i.id', 'i.title', 'ist.status', ],
+            from       => 'issue_status ist',
+            inner_join => 'issues i',
+            on    => 'i.issue_status_id =  ist.id',
+            where => {
+                'ist.project_id' => $project->[0],
                 do {
                     if ( $opts->{status} ) {
-                        ( 'issue_status.status' => $opts->{status} );
+                        ( 'ist.status' => $opts->{status} );
                     }
                     else {
                         ();
                     }
                 },
             },
-            order_by => 'id ASC',
+            order_by => 'i.id ASC',
         );
 
         next unless $data;
@@ -102,7 +96,7 @@ bif-list-issues - list projects' issues
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -138,7 +132,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
