@@ -6,7 +6,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/ qv case concat coalesce sq/;
 use Time::Duration qw/concise duration/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -15,7 +15,7 @@ sub run {
     my $db   = $self->db;
 
     my @projects = $db->xarrayrefs(
-        select => [ 'p.id', 'p.fullpath', 'p.hub_id' ],
+        select => [ 'p.id', 'p.path', 'p.hub_id' ],
         from   => 'projects p',
         do {
 
@@ -34,7 +34,7 @@ sub run {
         },
         left_join => 'hubs h',
         on        => 'h.id = p.hub_id',
-        order_by  => [ 'p.hub_id IS NOT NULL', 'path' ],
+        order_by  => 'path',
     );
 
     return $self->ok('ListTopics') unless @projects;
@@ -90,9 +90,9 @@ sub run {
             },
             union_all_select => [
                 qv('issue')->as('type'),
-                'project_issues.id AS id',
+                'i.id AS id',
                 concat(
-                    'issues.title',
+                    'i.title',
                     case (
                         when => 't.first_change_id > b.start',
                         then => qv( $yellow . ' [+]' . $reset ),
@@ -101,23 +101,21 @@ sub run {
                         else => qv(''),
                     )
                   )->as('title'),
-                'issue_status.status',
+                'ist.status',
                 "strftime('%s','now') - t.ctime AS age",
             ],
-            from       => 'issue_status',
-            inner_join => 'project_issues',
-            on         => 'project_issues.issue_status_id = issue_status.id',
-            inner_join => 'issues',
-            on         => 'issues.id = project_issues.issue_id',
+            from       => 'issue_status ist',
+            inner_join => 'issues i',
+            on         => 'i.issue_status_id = ist.id',
             inner_join => 'topics t',
-            on         => 't.id = issues.id',
+            on         => 't.id = i.id',
             left_join  => 'b',
             on         => 't.last_change_id BETWEEN b.start AND b.stop',
             where      => {
-                'issue_status.project_id' => $project->[0],
+                'ist.project_id' => $project->[0],
                 do {
                     if ( $opts->{status} ) {
-                        ( 'issue_status.status' => $opts->{status} );
+                        ( 'ist.status' => $opts->{status} );
                     }
                     else {
                         ();
@@ -153,7 +151,7 @@ sub run {
 
     print $table->render( $self->term_width ) . "\n";
 
-    $self->ok( 'ListTopics', \@projects );
+    return $self->ok( 'ListTopics', \@projects );
 }
 
 1;
@@ -167,7 +165,7 @@ bif-list-topics - list projects' tasks and issues
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -208,7 +206,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
