@@ -5,15 +5,18 @@ use feature 'state';
 use locale;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::log';
 
 sub run {
-    my $self  = shift;
-    my $opts  = $self->opts;
-    my $db    = $self->db;
-    my ($hub) = $self->get_hub( $opts->{name} );
-    my @locs  = $db->get_hub_repos( $hub->{id} );
+    my $self = shift;
+    my $opts = $self->opts;
+    my $db   = $self->db;
+    my $hub =
+        $opts->{id}
+      ? $self->get_hub( $opts->{id} )
+      : $self->get_hub( $opts->{name} );
+    my @locs = $db->get_hub_repos( $hub->{id} );
 
     my ( $dark, $reset ) = $self->colours(qw/dark reset/);
 
@@ -73,7 +76,7 @@ bif-log-hub - review the history of a hub
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -105,7 +108,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
