@@ -4,7 +4,7 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::log';
 
 sub run {
@@ -29,7 +29,7 @@ sub run {
             "$now - changes.mtime AS mtime_age",
             'changes.action',
             'COALESCE(changes.author,e.name) AS author',
-            'COALESCE(changes.email,ecm.mvalue) AS email',
+            'COALESCE(changes.author_contact,ecm.mvalue) AS contact',
             'changes.message',
             'changes_tree.depth',
             'project_status.status',
@@ -86,7 +86,7 @@ bif-log-project - review a project history
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -116,7 +116,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
