@@ -4,7 +4,7 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::log';
 
 sub run {
@@ -19,9 +19,9 @@ sub run {
     my $sth = $db->xprepare(
         select => [
             'task_deltas.task_id AS id',
-            'SUBSTR(t.uuid,1,8) AS uuid',
+            't.uuid AS uuid',
             concat( qv('c'), 'task_deltas.change_id' )->as('change_id'),
-            'SUBSTR(changes.uuid,1,8) AS change_uuid',
+            'changes.uuid AS change_uuid',
             'task_deltas.title',
             'changes.mtime AS mtime',
             "changes.mtimetz AS mtimetz",
@@ -29,10 +29,11 @@ sub run {
             "$now - changes.mtime AS mtime_age",
             'changes.action',
             'COALESCE(changes.author,e.name) AS author',
-            'COALESCE(changes.email,ecm.mvalue) AS email',
+            "COALESCE(changes.author_contact_method || ': ' || "
+              . "changes.author_contact, ecm.method || ': ' || "
+              . "ecm.mvalue) AS contact",
             'task_status.status',
             'task_status.status',
-            'projects.fullpath AS path',
             'projects.title AS project_title',
             'changes_tree.depth',
             'changes.message',
@@ -88,7 +89,7 @@ bif-log-task - review a task history
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -118,7 +119,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
