@@ -7,7 +7,7 @@ use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 use Path::Tiny qw/path/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -47,116 +47,70 @@ sub run {
       prompt( $spacer . 'Contact ' . ucfirst( $opts->{method} ) . ':', $email )
       || return $self->err( 'ValueRequired', 'value is required' );
 
-    $opts->{message} ||= "New identity for $opts->{name}";
+    $opts->{message} ||= '';
 
     $dbw->txn(
         sub {
-            my $id    = $dbw->nextval('topics');
-            my $ecmid = $dbw->nextval('topics');
-            my $uid;
+            $opts->{id}     = $dbw->nextval('topics');
+            $opts->{ecm_id} = $dbw->nextval('topics');
 
             if ( $opts->{self} ) {
-                $uid = $dbw->nextval('changes');
-                $dbw->xdo(
-                    insert_into => 'changes',
-                    values      => {
-                        id          => $uid,
-                        identity_id => $id,
-                        message     => $opts->{message},
-                    },
+                $opts->{change_id} = $self->new_change(
+                    author         => $opts->{name},
+                    author_contact => bv( $opts->{value}, DBI::SQL_VARCHAR ),
+                    author_contact_method => $opts->{method},
+                    author_shortname      => $opts->{shortname},
                 );
             }
             else {
-                $uid = $self->new_change( message => $opts->{message} );
+                $opts->{change_id} = $self->new_change();
             }
 
-            $dbw->xdo(
-                insert_into => 'func_new_topic',
-                values      => {
-                    change_id => $uid,
-                    id        => $id,
-                    kind      => 'identity',
-                },
-            );
-
-            $dbw->xdo(
-                insert_into => 'func_new_entity',
-                values      => {
-                    id        => $id,
-                    change_id => $uid,
-                    name      => $opts->{name},
-                },
-            );
-
             $dbw->xdo(
                 insert_into => 'func_new_identity',
                 values      => {
-                    id        => $id,
-                    change_id => $uid,
+                    id        => $opts->{id},
+                    change_id => $opts->{change_id},
+                    name      => $opts->{name},
                     shortname => $opts->{shortname},
+                    self      => $opts->{self},
                 },
             );
 
             $dbw->xdo(
-                insert_into => 'func_new_topic',
+                insert_into => 'func_new_identity_contact_method',
                 values      => {
-                    change_id => $uid,
-                    id        => $ecmid,
-                    kind      => 'entity_contact_method',
+                    change_id   => $opts->{change_id},
+                    id          => $opts->{ecm_id},
+                    identity_id => $opts->{id},
+                    method      => $opts->{method},
+                    mvalue      => bv( $opts->{value}, DBI::SQL_VARCHAR ),
                 },
             );
 
             $dbw->xdo(
-                insert_into => 'func_new_entity_contact_method',
+                insert_into => 'func_update_identity',
                 values      => {
-                    change_id => $uid,
-                    id        => $ecmid,
-                    entity_id => $id,
-                    method    => $opts->{method},
-                    mvalue    => bv( $opts->{value}, DBI::SQL_VARCHAR ),
+                    change_id                 => $opts->{change_id},
+                    id                        => $opts->{id},
+                    contact_id                => $opts->{id},
+                    default_contact_method_id => $opts->{ecm_id},
                 },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_update_entity',
-                values      => {
-                    change_id                 => $uid,
-                    id                        => $id,
-                    contact_id                => $id,
-                    default_contact_method_id => $ecmid,
-                },
+            my $path = $dbw->xval(
+                select => 'path',
+                from   => 'topic_path tp',
+                where  => { 'tp.id' => $opts->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'change_deltas',
-                values      => {
-                    change_id         => $uid,
-                    new               => 1,
-                    action_format     => "new identity (%s) $opts->{name}",
-                    action_topic_id_1 => $id,
-                },
+            $self->end_change(
+                id            => $opts->{change_id},
+                message       => $opts->{message},
+                action_format => "new identity %s ($path), "
+                  . "$opts->{name} ($opts->{shortname})",
+                action_topic_id_1 => $opts->{id},
             );
-
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
-            );
-
-            if ( $opts->{self} ) {
-                $dbw->xdo(
-                    insert_into => 'bifkv',
-                    values      => {
-                        key         => 'self',
-                        identity_id => $id,
-                    },
-                );
-            }
-
-            printf( "Identity created: %d\n", $id );
-
-            # For test scripts
-            $opts->{id}        = $id;
-            $opts->{change_id} = $uid;
         }
     );
 
@@ -174,7 +128,7 @@ bif-new-identity - create a new identity in the repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -226,7 +180,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
