@@ -7,7 +7,7 @@ use Config::Tiny;
 use Log::Any '$log';
 use Path::Tiny qw/path tempdir/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 has subref => ( is => 'ro', );
@@ -30,6 +30,11 @@ sub run {
 
     $self->repo($tempdir);
 
+    # Fake App::bif into thinking the database already exists
+    open( my $fh, '>', $tempdir->child( $self->dbfile( $self->DBVERSION ) ) )
+      or die "open: $!";
+    close($fh);
+
     my $dbw = $self->dbw;
 
     # On windows at least, an SQLite handle on the database prevents a
@@ -42,12 +47,13 @@ sub run {
         $dbw->txn(
             sub {
                 $|++;
-                printf "Creating repository: %s", $opts->{directory};
+                printf "Creating repository: %s ", $opts->{directory};
 
-                my ( $old, $new ) = $dbw->deploy;
-                print " (v$new)\n";
+                my ( $old, $new ) = $dbw->deploy( $self->DBVERSION );
+                printf "(v%d.%d)\n", $self->DBVERSION, $new;
 
-                $self->subref->($self) if $self->subref;
+                $self->subref->( $self, $self->DBVERSION, $new )
+                  if $self->subref;
             }
         );
     };
@@ -64,8 +70,8 @@ sub run {
         $conf->{'user.alias'}->{ls} =
           'list topics --status open --project-status run';
         $conf->{'user.alias'}->{lss} =
-          'list topics --status stalled --project-status run';
-        $conf->{'user.alias'}->{lsp} = 'list projects define plan run';
+          'list topics --status open --status stalled --project-status run';
+        $conf->{'user.alias'}->{l}   = 'list projects define plan run';
         $conf->{'user.alias'}->{lsi} = 'list identities';
 
         $conf->write( $tempdir->child('config') );
@@ -97,7 +103,7 @@ bif-new-repo -  create an empty repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -135,7 +141,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
