@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -18,11 +18,11 @@ sub run {
     if ( !$opts->{path} ) {
 
         my @paths = $dbw->xarrayrefs(
-            select    => 'p.fullpath',
+            select    => 'p.path',
             from      => 'projects p',
             left_join => 'hubs h',
             on        => 'h.id = p.hub_id',
-            order_by  => 'path',
+            order_by  => 'p.path',
         );
 
         if ( 0 == @paths ) {
@@ -61,48 +61,32 @@ sub run {
 
     $dbw->txn(
         sub {
-            my $id = $dbw->nextval('topics');
-            my $uid = $self->new_change( message => $opts->{message}, );
-
-            $dbw->xdo(
-                insert_into => 'func_new_topic',
-                values      => {
-                    change_id => $uid,
-                    id        => $id,
-                    kind      => 'task',
-                },
-            );
+            $opts->{id}        = $dbw->nextval('topics');
+            $opts->{change_id} = $self->new_change;
 
             $dbw->xdo(
                 insert_into => 'func_new_task',
                 values      => {
-                    id             => $id,
-                    change_id      => $uid,
+                    change_id      => $opts->{change_id},
+                    id             => $opts->{id},
                     task_status_id => $opts->{task_status_id},
                     title          => $opts->{title},
                 },
             );
 
-            $dbw->xdo(
-                insert_into => 'change_deltas',
-                values      => {
-                    change_id         => $uid,
-                    new               => 1,
-                    action_format     => 'new task (%s)',
-                    action_topic_id_1 => $id,
-                },
+            my $path = $dbw->xval(
+                select => 'path',
+                from   => 'topic_path tp',
+                where  => { 'tp.id' => $opts->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
+            $self->end_change(
+                id                => $opts->{change_id},
+                action_format     => "new task %s ($path)",
+                action_topic_id_1 => $opts->{id},
+                message           => $opts->{message},
             );
 
-            printf( "Task created: %d\n", $id );
-
-            # For test scripts
-            $opts->{id}        = $id;
-            $opts->{change_id} = $uid;
         }
     );
 
@@ -120,7 +104,7 @@ bif-new-task - add a new task to a project
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -171,7 +155,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
