@@ -9,7 +9,7 @@ use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 use Path::Tiny;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -21,9 +21,12 @@ sub run {
     my $dbw = $self->dbw;    # Consider upping PRAGMA cache_size?
                              #Or handle that in Bif::Role::Sync?
 
-    if ( $opts->{location} =~ m!^ssh://(.+)! ) {
+    if ( $opts->{location} =~ m!^(ssh://)?(.*)@(.*)! ) {
+        $opts->{name}     = $2;
+        $opts->{location} = path($3)->realpath;
     }
     elsif ( -d $opts->{location} ) {
+        ( $opts->{name} = $opts->{location} ) =~ s{/?(.*?)\.bif/?$}{$1};
         $opts->{location} = path( $opts->{location} )->realpath;
     }
     else {
@@ -45,7 +48,7 @@ sub run {
     my $cv = AE::cv;
 
     my $client = Bif::Sync::Client->new(
-        name          => $opts->{location},
+        name          => $opts->{name},
         db            => $dbw,
         location      => $opts->{location},
         debug         => $opts->{debug},
@@ -59,15 +62,14 @@ sub run {
         },
     );
 
+    my $fh   = select;
     my $coro = async {
-        select $App::bif::pager->fh if $opts->{debug};
+        select $fh;
 
         eval {
             $dbw->txn(
                 sub {
-                    my $uid = $dbw->nextval('changes');
-
-                    my ( $status, $ref ) = $client->pull_hub;
+                    my ( $status, $ref ) = $client->pull_hub( $opts->{name} );
 
                     print "\n";
 
@@ -80,9 +82,11 @@ sub run {
                     }
 
                     my @repos = $dbw->xhashrefs(
-                        select    => [ 'h.name', 'hr.id', 'hr.location' ],
-                        from      => 'hubs h',
-                        left_join => 'hub_repos hr',
+                        select     => [ 'p.name', 'hr.id', 'hr.location' ],
+                        from       => 'hubs h',
+                        inner_join => 'projects p',
+                        on         => 'p.id = h.id',
+                        left_join  => 'hub_repos hr',
                         on    => 'hr.hub_id = h.id',
                         where => { 'h.id' => $ref->[0] },
                         limit => 1,
@@ -104,34 +108,24 @@ sub run {
                         where  => { id => $ref->[0] },
                     );
 
-                    $self->new_change(
-                        id => $uid,
+                    $opts->{change_id} = $self->new_change;
+
+                    $self->end_change(
+                        id => $opts->{change_id},
+                        action_format =>
+                          "pull hub $opts->{name}\@$opts->{location}",
                         message =>
                           "Registered hub $repo->{name} at $opts->{location}",
                     );
 
-                    $dbw->xdo(
-                        insert_into => 'change_deltas',
-                        values      => {
-                            new           => 1,
-                            change_id     => $uid,
-                            action_format => "pull hub $repo->{name}",
-                        },
-                    );
-
-                    $dbw->xdo(
-                        insert_into => 'func_merge_changes',
-                        values      => { merge => 1 },
-                    );
-
                     $dbw->xdo(
                         insert_or_replace_into =>
                           [ 'bifkv', qw/key change_id change_id2/ ],
-                        select => [ qv('last_sync'), $uid, 'MAX(c.id)', ],
-                        from   => 'changes c',
+                        select =>
+                          [ qv('last_sync'), $opts->{change_id}, 'MAX(c.id)', ],
+                        from => 'changes c',
                     );
 
-                    print "Hub pulled: $repo->{name}\n";
                     return $status;
                 }
             );
@@ -162,7 +156,7 @@ bif-pull-hub -  import project lists from a remote repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -199,7 +193,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
