@@ -8,7 +8,7 @@ use Coro;
 use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -37,21 +37,13 @@ sub run {
         },
     );
 
+    my $fh   = select;
     my $coro = async {
-        select $App::bif::pager->fh if $opts->{debug};
+        select $fh;
 
         eval {
             $dbw->txn(
                 sub {
-                    my $uid = $dbw->nextval('changes');
-
-                    if ( !$opts->{self} ) {
-                        $self->new_change(
-                            id      => $uid,
-                            message => $opts->{message},
-                        );
-                    }
-
                     $|++;
                     my $status = $client->bootstrap_identity;
 
@@ -61,42 +53,45 @@ sub run {
                         return;
                     }
 
-                    if ( $opts->{self} ) {
-                        $self->new_change(
-                            id      => $uid,
-                            message => $opts->{message},
-                        );
-                    }
-
-                    my $iid = $dbw->xval(
-                        select => 'bifkv.identity_id',
-                        from   => 'bifkv',
-                        where  => { key => 'bootstrap' },
-                    );
-
-                    $dbw->xdo(
-                        insert_into => 'change_deltas',
-                        values      => {
-                            new       => 1,      # TODO why am I doing this?
-                            change_id => $uid,
-                            action_format     => 'pull identity %s',
-                            action_topic_id_1 => $iid,
-                        },
-                    );
-
+                    # Need to merge the identity received for the
+                    # end_change() method to succeed below
                     $dbw->xdo(
                         insert_into => 'func_merge_changes',
                         values      => { merge => 1 },
                     );
 
-                    $dbw->xdo(
-                        insert_or_replace_into =>
-                          [ 'bifkv', qw/key change_id change_id2/ ],
-                        select => [ qv('last_sync'), $uid, 'MAX(c.id)', ],
-                        from   => 'changes c',
+                    my ( $iid, $uuid, $name, $sn ) = $dbw->xlist(
+                        select => [
+                            'bifkv.identity_id',
+                            '"u" || substr(t.uuid,1,8) AS uuid',
+                            'e.name', 'i.shortname',
+                        ],
+                        from       => 'bifkv',
+                        inner_join => 'topics t',
+                        on         => 't.id = bifkv.identity_id',
+                        inner_join => 'identities i',
+                        on         => 'i.id = t.id',
+                        inner_join => 'entities e',
+                        on         => 'e.id = i.id',
+                        where      => { key => 'self' },
                     );
 
-                    print "\n";
+                    $self->end_change(
+                        id            => $self->new_change,
+                        message       => $opts->{message},
+                        action_format => $opts->{self}
+                        ? "pull identity %s [$uuid $name ($sn)] --self"
+                        : "pull identity %s [$uuid $name ($sn)]",
+                        action_topic_id_1 => $iid,
+                    );
+
+     #                    $dbw->xdo(
+     #                        insert_or_replace_into =>
+     #                          [ 'bifkv', qw/key change_id change_id2/ ],
+     #                        select => [ qv('last_sync'), $uid, 'MAX(c.id)', ],
+     #                        from   => 'changes c',
+     #                    );
+
                 }
             );
         };
@@ -124,7 +119,7 @@ bif-pull-identity - import an identity from a repository
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -154,7 +149,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
