@@ -5,39 +5,41 @@ use feature 'state';
 use Bif::Mo;
 use DBIx::ThinSQL qw/concat qv/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
-    my $info = $self->get_topic( $opts->{id} );
-
-    return $self->err( 'NotAnIssue', 'not an issue topic: ' . $info->{id} )
-      unless $info->{kind} eq 'issue';
-
-    my $dbw = $self->dbw;
+    my $info = $self->get_topic( $opts->{id}, 'issue' );
+    my $dbw  = $self->dbw;
 
     $dbw->txn(
         sub {
 
             foreach my $path ( @{ $opts->{path} } ) {
 
-                my $pinfo = $self->get_project( $path, $opts->{hub} );
+                my $pinfo = $self->get_project($path);
 
                 my $existing = $dbw->xval(
-                    select     => 'issue_status.status',
-                    from       => 'project_issues',
-                    inner_join => 'project_issues AS pi2',
+                    select     => 'ist.status',
+                    from       => 'issues i',
+                    inner_join => 'issues i2',
+                    on         => 'i2.id = i.src_id',
+                    inner_join => 'issue_status ist',
                     on         => {
-                        'pi2.issue_id'   => \'project_issues.issue_id',
-                        'pi2.project_id' => $pinfo->{id},
+                        'ist.id'         => \'i2.issue_status_id',
+                        'ist.project_id' => $pinfo->{id},
                     },
-                    inner_join => 'issue_status',
-                    on         => 'issue_status.id = pi2.issue_status_id',
-                    where      => {
-                        'project_issues.id' => $info->{project_issue_id},
+                    where        => { 'i.id' => $info->{id} },
+                    union_select => 'ist.status',
+                    from         => 'issues i',
+                    inner_join   => 'issue_status ist',
+                    on           => {
+                        'ist.id'         => \'i.issue_status_id',
+                        'ist.project_id' => $pinfo->{id},
                     },
+                    where => { 'i.src_id' => $info->{id} },
                 );
 
                 if ($existing) {
@@ -53,15 +55,20 @@ sub run {
                     }
                 }
 
+=cut
+
+# Not yet sure what I should be doing here. Will comment it out until
+# after the next issue reorganisation
+
                 my @unsatisfied = map { $_->[0] } $dbw->xarrayrefs(
-                    select        => 'p.fullpath',
+                    select        => 'p.path',
                     from          => 'project_issues pi',
                     inner_join    => 'projects p',
                     on            => 'p.id = pi.project_id',
                     inner_join    => 'hubs h',
                     on            => 'h.id = p.hub_id',
                     where         => { 'pi.issue_id' => $info->{id} },
-                    except_select => 'p2.fullpath',
+                    except_select => 'p2.path',
                     from          => 'projects p',
                     inner_join    => 'hub_related_projects hrp',
                     on            => 'hrp.hub_id = p.hub_id',
@@ -74,11 +81,11 @@ sub run {
 
                 if (@unsatisfied) {
                     my $name = $dbw->xval(
-                        select     => [ 'h.name', 'h.local' ],
+                        select     => ['p.name'],
                         from       => 'projects p',
                         inner_join => 'hubs h',
                         on         => 'h.id = p.hub_id',
-                        where => { 'p.id' => $pinfo->{id} },
+                        where      => { 'p.id' => $pinfo->{id} },
                     );
 
                     @unsatisfied = join ', ', @unsatisfied;
@@ -86,31 +93,14 @@ sub run {
                     return $self->err( 'NoCooperation',
                         "$path\@$name has no cooperation with @unsatisfied" );
                 }
+=cut
 
                 $opts->{message} ||= $self->prompt_edit;
 
-                my $src = $dbw->xval(
-                    select    => 'p.fullpath',
-                    from      => 'projects p',
-                    left_join => 'hubs h',
-                    on        => 'h.id = p.hub_id',
-                    where     => { 'p.id' => $info->{project_id}, },
-                );
+                $opts->{change_id} =
+                  $self->new_change( parent_id => $info->{first_change_id}, );
 
-                my $dest = $dbw->xval(
-                    select    => 'p.fullpath',
-                    from      => 'projects p',
-                    left_join => 'hubs h',
-                    on        => 'h.id = p.hub_id',
-                    where     => { 'p.id' => $pinfo->{id}, },
-                );
-
-                my $uid = $self->new_change(
-                    parent_id => $info->{first_change_id},
-                    message   => "[ forked: $src -> $dest ]\n\n"
-                      . $opts->{message},
-                    action => 'push issue',
-                );
+                $opts->{message} //= 'junk';
 
                 my $status_id = $dbw->xval(
                     select => 'id',
@@ -121,25 +111,45 @@ sub run {
                     },
                 );
 
+                my $id = $dbw->nextval('topics');
+
                 $dbw->xdo(
-                    insert_into => 'func_update_issue',
-                    values      => {
-                        change_id       => $uid,
-                        id              => $info->{id},
-                        project_id      => $pinfo->{id},
-                        issue_status_id => $status_id,
+                    insert_into => [
+                        'func_new_issue', qw/change_id id src_id
+                          issue_status_id title /
+                    ],
+                    select => [
+                        qv( $opts->{change_id} ), qv($id),
+                        qv( $info->{id} ),        qv($status_id),
+                        'i.title'
+                    ],
+                    from  => 'issues i',
+                    where => {
+                        'i.id' => $info->{id},
                     },
                 );
 
-                $opts->{change_id} = $uid;
+                my $src = $dbw->xval(
+                    select => 'tp.path',
+                    from   => 'topic_path tp',
+                    where  => { 'tp.id' => $info->{id}, },
+                );
 
-                $dbw->xdo(
-                    insert_into => 'func_merge_changes',
-                    values      => { merge => 1 },
+                my $dest = $dbw->xval(
+                    select => 'tp.path',
+                    from   => 'topic_path tp',
+                    where  => { 'tp.id' => $id, },
+                );
+
+                $self->end_change(
+                    id                => $opts->{change_id},
+                    action_format     => "push issue $src (%s) $dest (%s)",
+                    action_topic_id_1 => $info->{id},
+                    action_topic_id_2 => $pinfo->{id},
+                    message           => "[ forked: $src -> $dest ]\n\n"
+                      . $opts->{message},
                 );
 
-                printf( "Issue pushed: %d.%d\n",
-                    $opts->{id}, $opts->{change_id} );
             }
         }
     );
@@ -158,7 +168,7 @@ bif-push-issue - push an issue to another project
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -210,7 +220,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
