@@ -6,7 +6,7 @@ use Bif::Sync::Client;
 use Bif::Mo;
 use Coro;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -66,8 +66,9 @@ sub run {
         },
     );
 
+    my $fh   = select;
     my $coro = async {
-        select $App::bif::pager->fh if $opts->{debug};
+        select $fh;
 
         eval {
             $dbw->txn(
@@ -79,35 +80,26 @@ sub run {
                             $msg .= "\n\n$opts->{message}\n";
                         }
 
-                        my $uid = $self->new_change(
-                            parent_id => $pinfo->{first_change_id},
-                            message   => $msg,
-                        );
+                        $opts->{change_id} = $self->new_change(
+                            parent_id => $pinfo->{first_change_id}, );
 
                         $dbw->xdo(
                             insert_into => 'func_update_project',
                             values      => {
                                 id        => $pinfo->{id},
-                                change_id => $uid,
-                                hub_id    => $hub->{id},
+                                change_id => $opts->{change_id},
+                                parent_id => $hub->{id},
                             },
                         );
 
-                        $dbw->xdo(
-                            insert_into => 'change_deltas',
-                            values      => {
-                                change_id     => $uid,
-                                new           => 1,
-                                action_format => "push project $pinfo->{path} "
-                                  . "(%s) $hub->{name}",
-                                action_topic_id_1 => $pinfo->{id},
-                            },
+                        $self->end_change(
+                            id            => $opts->{change_id},
+                            action_format => "push project $pinfo->{path} "
+                              . "(%s) $hub->{name}",
+                            action_topic_id_1 => $pinfo->{id},
+                            message           => $msg,
                         );
 
-                        $dbw->xdo(
-                            insert_into => 'func_merge_changes',
-                            values      => { merge => 1 },
-                        );
                     }
 
                     my $status = $client->sync_hub( $hub->{id} );
@@ -174,7 +166,7 @@ bif-push-project -  export a project to a remote hub
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -213,7 +205,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
