@@ -5,15 +5,16 @@ use App::bif::log;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq qv/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
-    my $self = shift;
-    my $opts = $self->opts;
-    my $dbw  = $self->dbw;
-    my $info = $self->get_change( $opts->{uid} );
-    my $now  = $self->now;
+    my $self  = shift;
+    my $opts  = $self->opts;
+    my $dbw   = $self->dbw;
+    my $info  = $self->get_change( $opts->{uid} );
+    my $now   = $self->now;
+    my $devel = eval { require YAML::Tiny };
 
     my $ref = $dbw->xhashref(
         select => [
@@ -26,7 +27,7 @@ sub run {
             'c.action',
             'e.name',
             'COALESCE(c.author,e.name) AS author',
-            'COALESCE(c.email,ecm.mvalue) AS email',
+            'COALESCE(c.author_contact,ecm.mvalue) AS contact',
             'c.message',
         ],
         from       => 'changes c',
@@ -42,51 +43,78 @@ sub run {
     );
 
     # YAML::Tiny only installed by cpanm --with-develop
-    my $yaml    = '';
-    my $invalid = '';
+    my $yaml     = '';
+    my $ref_uuid = $ref->{uuid};
 
-    if ( eval { require YAML::Tiny } ) {
-        require Bif::DB::Plugin::Changes;
+    if ($devel) {
+        require Bif::DB::Plugin::ChangeUUIDv1;
         require Digest::SHA;
 
-        my $sth = $dbw->xprepare_changeset_ext(
-            with => 'src',
-            as   => sq(
-                select => qv( $info->{id} )->as('id'),
-            ),
-        );
+        my $changeset = $dbw->uchangeset_v1( $info->{id} );
 
-        $sth->execute;
-        my $ref2 = $sth->changeset_ext;
-        delete $ref2->[0]->{uuid};
+        my $begin = shift @$changeset;
+        my $end   = pop @$changeset;
+        my $uuid  = delete $end->{uuid};
+
+        foreach my $x (@$changeset) {
+            next
+              unless ref $x eq 'HASH'
+              && exists $x->{_delta}
+              && $x->{_delta} =~ m/^new_/;
+            delete $x->{uuid};
+        }
+
+        $yaml = YAML::Tiny::Dump( [ $begin, @$changeset, $end ] );
 
-        $yaml = YAML::Tiny::Dump($ref2);
         my ( $green, $red, $reset ) = $self->colours(qw/green red reset/);
 
-        $invalid =
-          Digest::SHA::sha1_hex($yaml) eq $ref->{uuid}
-          ? ' (' . $green . 'VALID' . $reset . ')'
-          : ' (' . $red . 'INVALID!' . $reset . ')';
+        $ref_uuid = $reset . $red . 'INVALID' . $reset
+          unless Digest::SHA::sha1_hex($yaml) eq $ref->{uuid};
+
+        if ( $opts->{diff} ) {
+            require Text::Diff;
+            my $terms = $dbw->xval(
+                select => 'c.yaml',
+                from   => 'changes c',
+                where  => { 'c.id' => $info->{id} },
+            );
+
+            my $diff =
+              Text::Diff::diff( \$terms, \$yaml, { CONTEXT => length $yaml } );
+
+            if ($diff) {
+                $diff =~ s/^\-(.*)/$red-$1$reset/mg;
+                $diff =~ s/^\+(.*)/$green+$1$reset/mg;
+                $diff =~ s/.*//;
+                $yaml = $diff;
+            }
+            else {
+                $yaml =~ s/^/ /mg;
+                $yaml = "\n" . $yaml;
+            }
+        }
+        else {
+            $yaml =~ s/^/ /mg;
+            $yaml = "\n" . $yaml;
+        }
+    }
+    else {
+        $yaml = "Details only shown when developer libraries installed\n";
     }
 
     my @data;
     push( @data,
-        $self->header( '  From', $ref->{author}, $ref->{email} ),
-        $self->header( '  When', $self->mtime_ago($ref) ),
-        $self->header( '  UUID', $ref->{uuid} . $invalid ),
+        $self->header( '  From',   $ref->{author}, $ref->{contact} ),
+        $self->header( '  When',   $self->mtime_ago($ref) ),
+        $self->header( '  Action', $ref->{action} ),
     );
 
     $self->start_pager;
 
     print $self->render_table( 'l  l',
-        [ 'a' . $ref->{id} . ':', $ref->{action} ],
-        \@data, 1 );
-
-    print "\n";
-    print App::bif::log->reformat( $ref->{message} );
-
-    ( my $x = $yaml ) =~ s/^/ /mg;
-    print $x;
+        $self->header( 'change', $ref->{id}, $ref_uuid ),
+        \@data, 1 ),
+      $yaml;
 
     return $self->ok('ShowChange');
 }
@@ -102,7 +130,7 @@ bif-show-change - show change information
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -138,7 +166,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
