@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
@@ -29,7 +29,7 @@ sub run {
             'c.mtimetzhm AS mtimetzhm',
             "$now - c.mtime AS mtime_age",
             'c.author',
-            'c.email',
+            'c.author_contact',
             'c.message',
             'e.local',
             'h.name AS hub_name',
@@ -52,8 +52,6 @@ sub run {
     return $self->err( 'EntityNotFound', "entity not found: $opts->{id}" )
       unless $ref;
 
-    my ($bold) = $self->colours('bold');
-
     push( @data,
         $self->header( '  UUID', $ref->{uuid} ),
         $self->header( '  Hub', $ref->{hub_name}, $ref->{hub_location} ),
@@ -87,8 +85,11 @@ sub run {
     ) for @methods;
 
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Entity', $ref->{name} ],
-        \@data, 1 );
+    print $self->render_table( 'l  l', [ 'Entity', $ref->{name} ], \@data, 1 );
+
+    print "\n";
+    $self->dispatch( 'App::bif::log::entity',
+        { opts => { id => $opts->{id} } } );
 
     return $self->ok( 'ShowEntity', \@data );
 }
@@ -104,7 +105,7 @@ bif-show-entity - display a entity's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -143,7 +144,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
