@@ -3,16 +3,15 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
-    my $self   = shift;
-    my $opts   = $self->opts;
-    my $db     = $self->db;
-    my $hub    = $self->get_hub( $opts->{name} );
-    my @repos  = $db->get_hub_repos( $hub->{id} );
-    my ($bold) = $self->colours('bold');
+    my $self  = shift;
+    my $opts  = $self->opts;
+    my $db    = $self->db;
+    my $hub   = $self->get_hub( $opts->{id} ? $opts->{id} : $opts->{name} );
+    my @repos = $db->get_hub_repos( $hub->{id} );
 
     my @data;
 
@@ -44,8 +43,10 @@ sub run {
     );
 
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Hub', $hub->{name} ], \@data,
-        1 );
+    print $self->render_table( 'l  l', [ 'Hub', $hub->{name} ], \@data, 1 );
+    print "\n";
+
+    $self->new_cmd( 'App::bif::log::hub', opts => { id => $hub->{id} } )->run;
 
     return $self->ok( 'ShowHub', \@data );
 }
@@ -61,7 +62,7 @@ bif-show-hub - display a hub's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -106,7 +107,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
