@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sum case coalesce concat qv/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
@@ -20,21 +20,11 @@ sub run {
     my $ref = $db->xhashref(
         select => [
             'i.id',
-            'substr(t.uuid,1,8) as uuid',
-            't.mtime AS mtime',
-            't.mtimetz AS mtimetz',
-            't.mtimetzhm AS mtimetzhm',
-            "$now - t.mtime AS mtime_age",
+            concat( qv('u'), 't.uuid' )->as('uuid'),
             'e.name',
+            'i.shortname',
             'ct.contact_id != e.id AS other_contact',
             'ct.name AS contact',
-            't.ctime AS ctime',
-            't.ctimetz AS ctimetz',
-            't.ctimetzhm AS ctimetzhm',
-            "$now - t.ctime AS ctime_age",
-            'c.author',
-            'c.email',
-            'c.message',
             'e.local',
         ],
         from       => 'identities i',
@@ -52,11 +42,20 @@ sub run {
     return $self->err( 'IdentityNotFound', "identity not found: $opts->{id}" )
       unless $ref;
 
-    my ($bold) = $self->colours('bold');
+    my $yellow = $self->colours('yellow');
 
-    push( @data, $self->header( '  UUID',    $ref->{uuid} ), );
-    push( @data, $self->header( '  Created', $self->ctime_ago($ref) ), );
-    push( @data, $self->header( '  Contact', $ref->{contact} ), )
+    push(
+        @data,
+        $self->header(
+            $yellow . 'Identity',
+            $yellow . $ref->{id},
+            $ref->{uuid}
+        ),
+        $self->header( 'Name',      $ref->{name} ),
+        $self->header( 'ShortName', $ref->{shortname} ),
+    );
+
+    push( @data, $self->header( 'Contact', $ref->{contact} ), )
       if $ref->{other_contact};
 
     my @methods = $db->xhashrefs(
@@ -82,11 +81,12 @@ sub run {
         ),
     ) for @methods;
 
-    push( @data, $self->header( '  Updated', $self->mtime_ago($ref) ), );
-
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Identity', $ref->{name} ],
-        \@data, 1 );
+    print $self->render_table( 'l  l', undef, \@data, 1 );
+
+    print "\n";
+    $self->dispatch( 'App::bif::log::identity',
+        { opts => { id => $opts->{id} } } );
 
     return $self->ok( 'ShowIdentity', \@data );
 }
@@ -102,7 +102,7 @@ bif-show-identity - display a identity's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -141,7 +141,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
