@@ -2,18 +2,20 @@ package App::bif::show::issue;
 use strict;
 use warnings;
 use Bif::Mo;
-use DBIx::ThinSQL qw/sum case coalesce concat qv/;
+use DBIx::ThinSQL qw/bv sum case coalesce concat qv sq/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
-    my $self   = shift;
-    my $opts   = $self->opts;
-    my $db     = $self->db;
-    my $info   = $self->get_topic( $self->uuid2id( $opts->{id} ), 'issue' );
-    my ($bold) = $self->colours('bold');
-    my $now    = $self->now;
+    my $self = shift;
+    my $opts = $self->opts;
+    my $db   = $self->db;
+
+    $opts->{id} = $self->uuid2id( $opts->{id} );
+
+    my $info = $self->get_topic( $opts->{id}, 'issue' );
+    my $now = $self->now;
     my @data;
 
     my $ref = $db->xhashref(
@@ -46,15 +48,38 @@ sub run {
     );
 
     push( @data, $self->header( '  UUID', $ref->{uuid} ), );
-    my ( $t1, $t2 ) = $self->ctime_ago($ref);
     push( @data,
-        $self->header( '  Created-By', "$ref->{creator} ($t1)", $t2 ),
+        $self->header( '  Created',    $self->ctime_ago($ref) ),
+        $self->header( '  Created-By', $ref->{creator} ),
     );
 
     my @refs = $db->xhashrefs(
+        with => 'ids',
+        as   => sq(
+
+            # self
+            select => bv( $info->{id}, DBI::SQL_INTEGER )->as('id'),
+
+            # parent
+            union_select => 'i.src_id',
+            from         => 'issues i',
+            where        => { 'i.id' => $info->{id} },
+
+            # siblings
+            union_select => 'i2.id',
+            from         => 'issues i',
+            inner_join   => 'issues i2',
+            on           => 'i2.src_id = i.src_id',
+            where        => { 'i.id' => $info->{id} },
+
+            # children
+            union_select => 'i.id',
+            from         => 'issues i',
+            where        => { 'i.src_id' => $info->{id} },
+        ),
         select => [
-            'pi.id AS id',
-            'p.fullpath AS path',
+            'i.id AS id',
+            'p.path',
             'ist.status',
             'c.mtime AS mtime',
             'c.mtimetz AS mtimetz',
@@ -62,17 +87,20 @@ sub run {
             "$now - c.mtime AS mtime_age",
             'p.hub_id',
         ],
-        from       => 'project_issues pi',
+        from       => 'ids',
+        inner_join => 'issues i',
+        on         => 'i.id = ids.id',
         inner_join => 'projects p',
-        on         => 'p.id = pi.project_id',
+        on         => 'p.id = i.project_id',
         left_join  => 'hubs h',
         on         => 'h.id = p.hub_id',
         inner_join => 'issue_status ist',
-        on         => 'ist.id = pi.issue_status_id',
+        on         => 'ist.id = i.issue_status_id',
+        inner_join => 'topics t',
+        on         => 't.id = i.id',
         inner_join => 'changes c',
-        on         => 'c.id = pi.change_id',
-        where      => { 'pi.issue_id' => $info->{id} },
-        order_by   => [ 'p.hub_id IS NOT NULL', 'path' ],
+        on         => 'c.id = t.first_change_id',
+        order_by   => 'p.path',
     );
 
     my %seen;
@@ -84,20 +112,24 @@ sub run {
         push(
             @data,
             $self->header(
-                '  Status', "$ref->{status} [$ref->{path}] (" . $ago[0] . ')',
+                '  Status',
+                "$ref->{path}/$ref->{id}: $ref->{status} (" . $ago[0] . ')',
                 $ago[1]
             ),
         );
     }
 
-    ( $t1, $t2 ) = $self->mtime_ago($ref);
     push( @data,
-        $self->header( '  Updated-By', "$ref->{updator} ($t1)", $t2 ),
+        $self->header( '  Updated',    $self->mtime_ago($ref) ),
+        $self->header( '  Updated-By', $ref->{updator} ),
     ) unless $ref->{mtime} == $ref->{ctime};
 
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Issue', $ref->{title} ],
-        \@data, 1 );
+    print $self->render_table( 'l  l', [ 'Issue', $ref->{title} ], \@data, 1 );
+
+    print "\n";
+    $self->dispatch( 'App::bif::log::issue',
+        { opts => { id => $opts->{id} } } );
 
     $self->ok( 'ShowIssue', \@data );
 }
@@ -113,7 +145,7 @@ bif-show-issue - display an issue's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -151,7 +183,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
