@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
@@ -26,7 +26,7 @@ sub run {
             "$now - t.mtime AS age", 't.mtime',
             't.mtimetz',             't.mtimetzhm AS mtimetzhm',
             "$now - t.mtime AS age", 'c.author',
-            'c.email',               'c.message',
+            'c.author_contact',      'c.message',
         ],
         from       => 'plans pl',
         inner_join => 'topics t',
@@ -43,8 +43,6 @@ sub run {
     return $self->err( 'PlanNotFound', "plan not found: $opts->{id}" )
       unless $ref;
 
-    my ($bold) = $self->colours('bold');
-
     push( @data,
         $self->header( '  UUID',     $ref->{uuid} ),
         $self->header( '  Name',     $ref->{name} ),
@@ -68,8 +66,7 @@ sub run {
     push( @data, $self->header( '  Host', $_->{name}, ) ) for @methods;
 
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Plan', $ref->{title} ],
-        \@data, 1 );
+    print $self->render_table( 'l  l', [ 'Plan', $ref->{title} ], \@data, 1 );
 
     return $self->ok( 'ShowPlan', \@data );
 }
@@ -85,7 +82,7 @@ bif-show-plan - display a plan's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -123,7 +120,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
