@@ -3,14 +3,14 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_project( $opts->{path} );
+    my $info = $self->get_project( $opts->{id} ? $opts->{id} : $opts->{path} );
     my $now  = $self->now;
 
     my @data;
@@ -32,12 +32,12 @@ sub run {
             'topics.mtimetzhm AS mtimetzhm',
             "$now - topics.mtime AS mtime_age",
             'changes.author',
-            'changes.email',
+            'changes.author_contact AS contact',
             'changes.message',
             'project_status.status',
             'project_status.status',
             'projects.local',
-            'h.name AS hub',
+            'hp.name AS hub',
             't2.uuid AS hub_uuid',
             'hr.location',
         ],
@@ -48,6 +48,8 @@ sub run {
         on         => 'changes.id = topics.first_change_id',
         inner_join => 'project_status',
         on         => 'project_status.id = projects.project_status_id',
+        left_join  => 'projects hp',
+        on         => 'hp.id = projects.hub_id',
         left_join  => 'hubs h',
         on         => 'h.id = projects.hub_id',
         left_join  => 'hub_repos hr',
@@ -57,16 +59,13 @@ sub run {
         where      => { 'projects.id' => $info->{id} },
     );
 
-    my ($bold) = $self->colours('bold');
-
     push( @data, $self->header( '  Path', $ref->{path}, $ref->{uuid} ), );
-
-    push( @data, $self->header( '  Hub', $ref->{hub}, $ref->{location} ), )
+    push( @data, $self->header( '  Hub',  $ref->{hub},  $ref->{location} ), )
       if $ref->{hub};
 
     if ( $opts->{full} ) {
         push( @data,
-            $self->header( '  Creator', $ref->{author}, $ref->{email} ),
+            $self->header( '  Creator', $ref->{author}, $ref->{contact} ),
             $self->header( '  Created', $self->ctime_ago($ref) ),
         );
     }
@@ -91,15 +90,18 @@ sub run {
     if ( $ref->{local} ) {
         my ( $ai, $si, $ri, $ii ) = $db->xlist(
             select => [
-                coalesce( sum( { status => 'open' } ),    0 )->as('open'),
-                coalesce( sum( { status => 'stalled' } ), 0 )->as('stalled'),
-                coalesce( sum( { status => 'closed' } ),  0 )->as('closed'),
-                coalesce( sum( { status => 'ignored' } ), 0 )->as('ignored'),
+                coalesce( sum( { 'ist.status' => 'open' } ),    0 )->as('open'),
+                coalesce( sum( { 'ist.status' => 'stalled' } ), 0 )
+                  ->as('stalled'),
+                coalesce( sum( { 'ist.status' => 'closed' } ), 0 )
+                  ->as('closed'),
+                coalesce( sum( { 'ist.status' => 'ignored' } ), 0 )
+                  ->as('ignored'),
             ],
-            from       => 'project_issues',
-            inner_join => 'issue_status',
-            on         => 'issue_status.id = project_issues.issue_status_id',
-            where      => { 'project_issues.project_id' => $info->{id} },
+            from       => 'issue_status ist',
+            inner_join => 'issues i',
+            on         => 'i.issue_status_id = ist.id',
+            where      => { 'ist.project_id' => $info->{id} },
         );
 
         my ( $at, $st, $rt, $it ) = $db->xlist(
@@ -154,8 +156,12 @@ sub run {
         );
     }
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Project', $ref->{title} ],
-        \@data, 1 );
+    print $self->render_table( 'l  l', [ 'Project', $ref->{title} ], \@data,
+        1 );
+
+    print "\n";
+    $self->dispatch( 'App::bif::log::project',
+        { opts => { path => $info->{path} } } );
 
     return $self->ok( 'ShowProject', \@data );
 }
@@ -171,7 +177,7 @@ bif-show-project - display a project's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -221,7 +227,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
