@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
@@ -49,13 +49,13 @@ __END__
 
 =head1 NAME
 
-=for bif-doc #show
+=for bif-doc #devadmin
 
 bif-show-table - display a table's SQL schema
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -68,7 +68,7 @@ repository.
 
     bif show table projects
     # CREATE TABLE topics (
-    #     id INT NOT NULL PRIMARY KEY,
+    #     id INTEGER NOT NULL PRIMARY KEY,
     #     uuid char(40) NOT NULL UNIQUE,
     #     first_change_id INTEGER NOT NULL,
     #     last_change_id INTEGER NOT NULL,
@@ -109,7 +109,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
