@@ -3,24 +3,27 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif::show';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_topic( $self->uuid2id( $opts->{id} ), 'task' );
-    my $now  = $self->now;
+
+    $opts->{id} = $self->uuid2id( $opts->{id} );
+
+    my $info = $self->get_topic( $opts->{id}, 'task' );
+    my $now = $self->now;
 
     DBIx::ThinSQL->import(qw/sum qv concat coalesce/);
 
     my $ref = $db->xhashref(
         select => [
             't.id AS id',
-            'substr(t.uuid,1,8) as uuid',
-            'p.fullpath AS path',
-            'h.name AS hub',
+            't.uuid as uuid',
+            'tp.path AS path',
+            'hp.name AS hub',
             'hr.location',
             'substr(t2.uuid,1,8) AS project_uuid',
             'tasks.title AS title',
@@ -33,7 +36,7 @@ sub run {
             'c2.mtimetzhm AS mtimetzhm',
             "$now - c2.mtime AS mtime_age",
             'c1.author AS author',
-            'c1.email AS email',
+            "c1.author_contact_method || ': ' || c1.author_contact AS contact",
             'c1.message AS message',
             'ts.status AS status',
             'c12.mtime AS smtime',
@@ -55,6 +58,8 @@ sub run {
         on         => 'ts.id = tasks.task_status_id',
         inner_join => 'projects p',
         on         => 'p.id = ts.project_id',
+        left_join  => 'projects hp',
+        on         => 'hp.id = p.hub_id',
         left_join  => 'hubs h',
         on         => 'h.id = p.hub_id',
         left_join  => 'hub_repos hr',
@@ -63,19 +68,33 @@ sub run {
         on         => 't2.id = p.id',
         inner_join => 'changes AS c12',
         on         => 'c12.id = tasks.change_id',
+        inner_join => 'topic_path tp',
+        on         => 'tp.id = t.id',
         where      => [ 't.id = ', qv( $info->{id} ) ],
     );
 
     my @data;
-    my ($bold) = $self->colours('bold');
-
-    push( @data, $self->header( '  UUID', $ref->{uuid} ) );
     my ( $t1, $t2 ) = $self->ctime_ago($ref);
-    push( @data,
-        $self->header( '  Created-By', "$ref->{creator} ($t1)", $t2 ),
+
+    my $yellow = $self->colours('yellow');
+
+    push(
+        @data,
+        $self->header(
+            $yellow . 'Task',
+            $yellow . $ref->{id},
+            $yellow . $ref->{uuid}
+        )
     );
 
-    push( @data, $self->header( '  Status', "$ref->{status} [$ref->{path}]" ) );
+    push( @data, $self->header( ' Title', $ref->{title} ) );
+
+    push(
+        @data,
+        $self->header(
+            '  Status', "$ref->{status} [$ref->{path} ($ref->{id})]"
+        )
+    );
 
     if ( $opts->{full} ) {
         require Text::Autoformat;
@@ -95,13 +114,12 @@ sub run {
     }
 
     ( $t1, $t2 ) = $self->mtime_ago($ref);
-    push( @data,
-        $self->header( '  Updated-By', "$ref->{updator} ($t1)", $t2 ),
-    ) unless $ref->{mtime} == $ref->{ctime};
 
     $self->start_pager;
-    print $self->render_table( 'l  l', [ $bold . 'Task', $ref->{title} ],
-        \@data, 1 );
+    print $self->render_table( 'l  l', undef, \@data, 1 );
+
+    print "\n";
+    $self->dispatch( 'App::bif::log::task', { opts => { id => $opts->{id} } } );
 
     $self->ok( 'ShowTask', \@data );
 
@@ -118,7 +136,7 @@ bif-show-task - display a task's current status
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -156,7 +174,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Mark Lawrence <nomad@null.net>
+Copyright 2014-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
