@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -23,7 +23,7 @@ sub run {
         $opts->{statement} = <STDIN>;
     }
 
-    if ( $opts->{statement} =~ m/^(select)|(pragma)|(explain)/i ) {
+    if ( $opts->{statement} =~ m/^\s*(select)|(pragma)|(explain)|(with)/i ) {
         my $sth = $db->prepare( $opts->{statement} );
         $sth->execute(@_);
 
@@ -44,7 +44,14 @@ sub run {
 
         $self->start_pager;
 
-        print $self->render_table( $header, $sth->{NAME}, $data );
+        if ( $opts->{test} ) {
+            require Test::More;
+            Test::More::diag(
+                $self->render_table( $header, $sth->{NAME}, $data ) );
+        }
+        else {
+            print $self->render_table( $header, $sth->{NAME}, $data );
+        }
 
     }
     else {
@@ -65,7 +72,7 @@ bif-sql -  run an SQL command against the database
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -105,6 +112,11 @@ Do not print results but return them to the calling subroutine as a
 Perl data structure.  This option is only useful for internal test
 scripts.
 
+=item --test, -t
+
+Send the output to L<Test::More>'s C<diag> function. Useful for
+debugging database state when running tests.
+
 =item --user, -U
 
 Run the statement against the user identity database instead of against
@@ -126,7 +138,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
