@@ -7,7 +7,7 @@ use Bif::Mo;
 use Coro;
 use DBIx::ThinSQL qw/qv/;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -25,17 +25,16 @@ sub run {
 
     # Consider upping PRAGMA cache_size? Or handle that in Bif::Role::Sync?
     my @hubs = $dbw->xhashrefs(
-        select     => [ 'h.id', 'h.name', 'hr.location', 't.uuid' ],
+        select     => [ 'h.id', 'p.name', 'hr.location', 't.uuid' ],
         from       => 'hubs h',
         inner_join => 'topics t',
         on         => 't.id = h.id',
+        inner_join => 'projects p',
+        on         => 'p.id = h.id',
         inner_join => 'hub_repos hr',
-        on    => 'hr.id = h.default_repo_id',
-        where => {
-            'h.local' => undef,
-            $opts->{hub} ? ( 'h.name' => $opts->{hub} ) : (),
-        },
-        order_by => 'h.name',
+        on => 'hr.id = h.default_repo_id',
+        $opts->{hub} ? ( where => { 'p.name' => $opts->{hub} } ) : (),
+        order_by => 'p.name',
     );
 
     return $self->err( 'SyncNone', 'no (matching) hubs found' )
@@ -62,14 +61,13 @@ sub run {
             },
         );
 
+        my $fh   = select;
         my $coro = async {
-            select $App::bif::pager->fh if $opts->{debug};
+            select $fh;
 
             eval {
                 $dbw->txn(
                     sub {
-                        my $uid = $dbw->nextval('changes');
-
                         my $status = $client->sync_hub( $hub->{id} );
 
                         unless ( $status eq 'RepoMatch'
@@ -107,33 +105,26 @@ sub run {
                         }
                         print "\n";
 
-                        $self->new_change(
-                            id => $uid,
+                        $opts->{change_id} = $self->new_change;
+
+                        $self->end_change(
+                            id            => $opts->{change_id},
+                            action_format => "sync hub $hub->{name}\@"
+                              . "$hub->{location} (%s)",
+                            action_topic_id_1 => $hub->{id},
                             message =>
                               "sync hub $hub->{name} via $hub->{location}"
                               . $opts->{message},
                         );
 
-                        $dbw->xdo(
-                            insert_into => 'change_deltas',
-                            values      => {
-                                new           => 1,
-                                change_id     => $uid,
-                                action_format => "sync hub $hub->{name} (%s)",
-                                action_topic_id_1 => $hub->{id},
-                            },
-                        );
-
-                        $dbw->xdo(
-                            insert_into => 'func_merge_changes',
-                            values      => { merge => 1 },
-                        );
-
                         $dbw->xdo(
                             insert_or_replace_into =>
                               [ 'bifkv', qw/key change_id change_id2/ ],
-                            select => [ qv('last_sync'), $uid, 'MAX(c.id)', ],
-                            from   => 'changes c',
+                            select => [
+                                qv('last_sync'), $opts->{change_id},
+                                'MAX(c.id)',
+                            ],
+                            from => 'changes c',
                         );
 
                         return;
@@ -177,7 +168,7 @@ bif-sync -  exchange changes with hubs
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -212,7 +203,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
