@@ -3,26 +3,22 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
-    my $self  = shift;
-    my $opts  = $self->opts;
-    my $info  = $self->get_topic( $self->uuid2id( $opts->{id} ) );
-    my $class = "App::bif::update::$info->{kind}";
+    my $self = shift;
+    my $opts = $self->opts;
+    my $info = $self->get_topic( $self->uuid2id( $opts->{id} ) );
 
-    if ( eval "require $class" ) {
-        $opts->{path} = delete $opts->{id}
-          if ( $info->{kind} eq 'project' );
-
-        return $class->can('run')->($self);
-    }
-
-    die $@ if $@;
-
-    return $self->err( 'ChangeUnimplemented',
-        'cannnot change type: ' . $info->{kind} );
+    return $self->new_cmd(
+        "App::bif::update::$info->{kind}",
+        opts => {
+            id      => $info->{id},
+            title   => $opts->{title},
+            message => $opts->{message}
+        }
+    )->run;
 }
 
 1;
@@ -36,7 +32,7 @@ bif-update - change or comment a topic
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -90,7 +86,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
