@@ -3,14 +3,14 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
-    my $info = $self->get_hub( $opts->{id} );
+    my $info = $self->get_hub( $opts->{id} ? $opts->{id} : $opts->{name} );
 
     if ( $opts->{reply} ) {
         my $uinfo =
@@ -25,36 +25,32 @@ sub run {
 
     $dbw->txn(
         sub {
-            my $uid = $self->new_change(
-                message   => $opts->{message},
-                parent_id => $opts->{parent_uid},
-            );
+            $opts->{change_id} =
+              $self->new_change( parent_id => $opts->{parent_uid} );
 
             $dbw->xdo(
                 insert_into => 'func_update_hub',
                 values      => {
-                    change_id => $uid,
+                    change_id => $opts->{change_id},
                     id        => $info->{id},
                     name      => $opts->{name},
+                    title     => $opts->{title},
                 },
             );
 
-            $dbw->xdo(
-                insert_into => 'change_deltas',
-                values      => {
-                    change_id         => $uid,
-                    new               => 1,
-                    action_format     => "update hub $opts->{id} (%s)",
-                    action_topic_id_1 => $info->{id},
-                },
+            my $path = $dbw->xval(
+                select => 'path',
+                from   => 'topic_path tp',
+                where  => { 'tp.id' => $opts->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
+            $self->end_change(
+                id                => $opts->{change_id},
+                action_format     => "update hub $path (%s)",
+                action_topic_id_1 => $info->{id},
+                message           => $opts->{message},
             );
 
-            print "Hub changed: $opts->{id}.$uid\n";
         }
     );
 
@@ -72,7 +68,7 @@ bif-update-hub - update or comment a hub
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -111,7 +107,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
