@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -28,39 +28,32 @@ sub run {
 
     $dbw->txn(
         sub {
-            my $uid = $self->new_change(
-                message   => $opts->{message},
-                parent_id => $opts->{parent_uid},
-            );
+            $opts->{change_id} =
+              $self->new_change( parent_id => $opts->{parent_uid}, );
 
             $dbw->xdo(
-
-                # TODO This shuld be change_entity
                 insert_into => 'func_update_identity',
                 values      => {
-                    change_id => $uid,
+                    change_id => $opts->{change_id},
                     id        => $info->{id},
                     name      => $opts->{name},
                     shortname => $opts->{shortname},
                 },
             );
 
-            $dbw->xdo(
-                insert_into => 'change_deltas',
-                values      => {
-                    change_id         => $uid,
-                    new               => 1,
-                    action_format     => "update identity %s",
-                    action_topic_id_1 => $info->{id},
-                },
+            my $path = $dbw->xval(
+                select => 'path',
+                from   => 'topic_path tp',
+                where  => { 'tp.id' => $opts->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
+            $self->end_change(
+                id                => $opts->{change_id},
+                message           => $opts->{message},
+                action_format     => "update identity %s ($path)",
+                action_topic_id_1 => $info->{id},
             );
 
-            print "Identity changed: $opts->{id}.$uid\n";
         }
     );
 
@@ -78,7 +71,7 @@ bif-update-identity - update or comment an identity
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -121,7 +114,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
