@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -13,13 +13,13 @@ sub run {
     my $info = $self->get_topic( $self->uuid2id( $opts->{id} ), 'issue' );
 
     my $project_id = $dbw->xval(
-        select => 'project_issues.project_id',
-        from   => 'project_issues',
-        where  => { 'project_issues.id' => $info->{id} },
+        select => 'i.project_id',
+        from   => 'issues i',
+        where  => { 'i.id' => $info->{id} },
     );
 
     my ( $status_ids, $invalid ) =
-      $dbw->status_ids( $info->{project_id}, 'issue', $opts->{status} );
+      $dbw->status_ids( $project_id, 'issue', $opts->{status} );
 
     return $self->err( 'InvalidStatus',
         'unknown status(s): ' . join( ', ', @$invalid ) )
@@ -38,52 +38,35 @@ sub run {
 
     $dbw->txn(
         sub {
-            my $path = $dbw->xval(
-                select => 'p.path',
-                from   => 'projects p',
-                where  => { 'p.id' => $info->{project_id} },
-            );
-
-            $opts->{change_id} = $self->new_change(
-                message   => $opts->{message},
-                parent_id => $opts->{parent_uid},
-            );
+            $opts->{change_id} =
+              $self->new_change( parent_id => $opts->{parent_uid}, );
 
             $dbw->xdo(
                 insert_into => 'func_update_issue',
                 values      => {
-                    id         => $info->{id},
-                    change_id  => $opts->{change_id},
-                    project_id => $info->{project_id},
+                    id        => $info->{id},
+                    change_id => $opts->{change_id},
                     $opts->{title} ? ( title => $opts->{title} ) : (),
                     @$status_ids ? ( issue_status_id => $status_ids->[0] ) : (),
                 },
             );
 
-            $dbw->xdo(
-                insert_into => 'change_deltas',
-                values      => {
-                    change_id         => $opts->{change_id},
-                    new               => 1,
-                    action_format     => "update issue %s",
-                    action_topic_id_1 => $info->{id},
-                },
+            my $path = $dbw->xval(
+                select => 'path',
+                from   => 'topic_path tp',
+                where  => { 'tp.id' => $opts->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
+            $self->end_change(
+                id                => $opts->{change_id},
+                action_format     => "update issue %s ($path)",
+                action_topic_id_1 => $info->{id},
+                message           => $opts->{message},
             );
 
         }
     );
 
-    print "Issue changed: $info->{project_issue_id}.$opts->{change_id}\n";
-
-    # For testing
-    $opts->{id}               = $info->{id};
-    $opts->{parent_change_id} = $info->{change_id};
-    $opts->{status}           = $status_ids;
     return $self->ok('ChangeIssue');
 }
 
@@ -98,7 +81,7 @@ bif-update-issue - update an issue
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -150,7 +133,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
