@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'App::bif';
 
 sub run {
@@ -43,20 +43,8 @@ sub run {
 
     $dbw->txn(
         sub {
-            my $path = $dbw->xval(
-                select     => 'p.path',
-                from       => 'tasks t',
-                inner_join => 'task_status ts',
-                on         => 'ts.id = t.task_status_id',
-                inner_join => 'projects p',
-                on         => 'p.id = ts.project_id',
-                where      => { 't.id' => $info->{id} },
-            );
-
-            $opts->{change_id} = $self->new_change(
-                message   => $opts->{message},
-                parent_id => $opts->{parent_uid},
-            );
+            $opts->{change_id} =
+              $self->new_change( parent_id => $opts->{parent_uid}, );
 
             $dbw->xdo(
                 insert_into => 'func_update_task',
@@ -68,29 +56,22 @@ sub run {
                 },
             );
 
-            $dbw->xdo(
-                insert_into => 'change_deltas',
-                values      => {
-                    change_id         => $opts->{change_id},
-                    new               => 1,
-                    action_format     => 'update task %s',
-                    action_topic_id_1 => $info->{id},
-                },
+            my $path = $dbw->xval(
+                select => 'path',
+                from   => 'topic_path tp',
+                where  => { 'tp.id' => $opts->{id} },
             );
 
-            $dbw->xdo(
-                insert_into => 'func_merge_changes',
-                values      => { merge => 1 },
+            $self->end_change(
+                id                => $opts->{change_id},
+                action_format     => "update task %s ($path)",
+                action_topic_id_1 => $info->{id},
+                message           => $opts->{message},
             );
 
-            print "Task changed: $info->{id}.$opts->{change_id}\n";
         }
     );
 
-    # For testing
-    $opts->{id}               = $info->{id};
-    $opts->{parent_change_id} = $info->{change_id};
-    $opts->{status}           = $status_ids;
     return $self->ok('ChangeTask');
 }
 
@@ -105,7 +86,7 @@ bif-update-task - update a task
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -157,7 +138,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
