@@ -13,7 +13,10 @@ use Log::Any::Plugin;
 use OptArgs;
 use Path::Tiny;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
+
+sub DBVERSION { 1 }
+sub DBFILE    { 'db-v' . DBVERSION . '.sqlite3' }
 
 arg directory => (
     isa     => 'Str',
@@ -42,9 +45,8 @@ sub run {
     $|++;
     select $tmp;
 
-    my $f      = 'db.sqlite3';
     my $dir    = path( $opts->{directory} );
-    my $sqlite = $dir->child($f);
+    my $sqlite = $dir->child(DBFILE);
 
     die Bif::Error->new( $opts, 'RepoNotFound', "directory not found: $dir\n" )
       unless -e $dir;
@@ -117,7 +119,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
