@@ -6,7 +6,7 @@ use DBIx::ThinSQL ();
 use Carp          ();
 use Log::Any '$log';
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 our @ISA     = ('DBIx::ThinSQL');
 
 sub _connected {
@@ -17,24 +17,12 @@ sub _connected {
 
     # $dbh->trace('1|SQL',\*STDOUT) if $debug;
 
+    $dbh->do('PRAGMA query_only = ON;');
     $dbh->do('PRAGMA foreign_keys = ON;');
     $dbh->do('PRAGMA temp_store = MEMORY;');
 
-    # TODO remove these before the first production release.
-    {
-        $dbh->do('PRAGMA reverse_unordered_selects = ON;');
-
-        $dbh->sqlite_set_authorizer(
-            sub {
-                return
-                     $_[0] == DBD::SQLite::SELECT
-                  || $_[0] == DBD::SQLite::READ
-                  || $_[0] == DBD::SQLite::FUNCTION
-                  ? DBD::SQLite::OK
-                  : DBD::SQLite::DENY;
-            }
-        );
-    }
+    # TODO remove before the first production release.
+    $dbh->do('PRAGMA reverse_unordered_selects = ON;');
     return;
 }
 
@@ -70,31 +58,17 @@ sub uuid2id {
         # In this case we know we will only get one match back
 
         return $self->xarrayref(
-            select    => [ coalesce( 'pi.id', 't.id' )->as('id'), 't.uuid', ],
-            from      => 'topics t',
-            left_join => 'project_issues pi',
-            on        => 'pi.issue_id = t.id',
-            where     => {
-                't.uuid' => $uuid
-            },
+            select => [ 't.id', 't.uuid', ],
+            from   => 'topics t',
+            where => { 't.uuid' => $uuid },
             limit => 1,
         );
     }
 
-    # In this case we could get multiple issue ID back, so we group on
-    # the issue_id
-
     return $self->xarrayrefs(
-        select_distinct => [
-            coalesce( 'pi.id', 't.id' )->as('id'),
-            't.uuid AS uuid',
-            'COUNT(t.uuid)',
-        ],
-        from      => 'topics t',
-        left_join => 'project_issues pi',
-        on        => 'pi.issue_id = t.id',
-        where     => [ 't.uuid LIKE ', qv( $uuid . '%' ) ],
-        group_by  => [ 'COALESCE(pi.id,t.id)', qw/t.uuid/ ],
+        select_distinct => [ 't.id',         't.uuid AS uuid', ],
+        from            => 'topics t',
+        where           => [ 't.uuid LIKE ', qv( $uuid . '%' ) ],
     );
 }
 
@@ -107,32 +81,14 @@ sub get_change {
         my $change_id = $2;
         my $data      = $self->xhashref(
             select => [
-                'topics.id',
-                'topics.kind',
-                'topics.uuid',
-                'changes.id AS change_id',
-                qv(undef)->as('project_issue_id'),
+                'topics.id',   'topics.kind',
+                'topics.uuid', 'changes.id AS change_id',
                 qv(undef)->as('project_id'),
             ],
             from       => 'topics',
             inner_join => 'changes',
             on         => { 'changes.id' => $change_id },
-            where =>
-              [ 'topics.id = ', bv($id), ' AND topics.kind != ', qv('issue') ],
-            union_all_select => [
-                'topics.id',
-                'topics.kind',
-                'topics.uuid',
-                'changes.id AS change_id',
-                'project_issues.id AS project_issue_id',
-                'project_issues.project_id',
-            ],
-            from       => 'project_issues',
-            inner_join => 'topics',
-            on         => 'topics.id = project_issues.issue_id',
-            inner_join => 'changes',
-            on         => { 'changes.id' => $change_id },
-            where      => { 'project_issues.id' => $id },
+            where      => { 'topics.id' => $id },
         );
         return $data;
     }
@@ -144,9 +100,9 @@ sub get_local_hub_id {
     my $self = shift;
 
     my $id = $self->xval(
-        select => ['hubs.id'],
-        from   => 'hubs',
-        where  => { 'hubs.local' => 1 },
+        select => 'b.hub_id',
+        from   => 'bifkv b',
+        where  => { 'b.key' => 'local_hub' },
     );
 
     return $id;
@@ -155,46 +111,48 @@ sub get_local_hub_id {
 sub get_projects {
     my $self = shift;
     my $path = shift || return;
-    my $hub  = shift;
 
-    if ($hub) {
+    if ( $path =~ m/^\d+$/ ) {
         return $self->xhashrefs(
             select => [
-                't.id',     't.kind',
-                't.uuid',   'p.parent_id',
-                'p.path',   't.first_change_id',
-                'p.hub_id', 'p.local',
+                't.id AS id',
+                't.kind AS kind',
+                't.uuid AS uuid',
+                'p.parent_id AS parent_id',
+                'p.path AS path',
+                't.first_change_id AS first_change_id',
+                'p.hub_id AS hub_id',
+                'p.local AS local',
                 'h.name AS hub_name',
             ],
             from       => 'projects p',
-            inner_join => 'hubs h',
-            on         => {
-                'h.id'   => \'p.hub_id',
-                'h.name' => $hub,
-            },
             inner_join => 'topics t',
             on         => 't.id = p.id',
-            where      => { 'p.path' => $path },
+            left_join  => 'projects h',
+            on         => 'h.id = p.hub_id',
+            where      => { 'p.id' => $path },
         );
     }
 
     return $self->xhashrefs(
         select => [
-            't.id',     't.kind',
-            't.uuid',   'p.parent_id',
-            'p.path',   't.first_change_id',
-            'p.hub_id', 'p.local',
+            't.id AS id',
+            't.kind AS kind',
+            't.uuid AS uuid',
+            'p.parent_id AS parent_id',
+            'p.path AS path',
+            't.first_change_id AS first_change_id',
+            'p.hub_id AS hub_id',
+            'p.local AS local',
             'h.name AS hub_name',
         ],
         from       => 'projects p',
         inner_join => 'topics t',
         on         => 't.id = p.id',
-        left_join  => 'hubs h',
+        left_join  => 'projects h',
         on         => 'h.id = p.hub_id',
-        where      => {
-            'p.path' => $path,
-        },
-        order_by => [qw/hub_name p.path/],
+        where      => [ 'p.path = ', qv($path), ' OR p.name = ', qv($path) ],
+        order_by   => [qw/p.path/],
     );
 }
 
@@ -231,28 +189,32 @@ sub get_hub_repos {
 
         # TODO get rid of this select once everything uses ctx->uuid2id
         select => [
-            'h.id AS id',
+            'p.id AS id',
             't.uuid AS uuid',
-            'h.name AS name',
+            'p.name AS name',
             'hr.location AS location',
             'h.default_repo_id = hr.id AS is_default'
         ],
-        from       => 'hubs h',
+        from       => 'projects p',
+        inner_join => 'hubs h',
+        on         => 'h.id = p.id',
         inner_join => 'topics t',
         on         => 't.id = h.id',
         inner_join => 'hub_repos hr',
         on         => 'hr.hub_id = h.id',
         where      => {
-            'h.name' => $hub,
+            'p.name' => $hub,
         },
         union_all_select => [
             'h.id AS id',
             't.uuid AS uuid',
-            'h.name AS name',
+            'p.name AS name',
             'hr.location AS location',
             'h.default_repo_id = hr.id AS is_default'
         ],
-        from       => 'hubs h',
+        from       => 'projects p',
+        inner_join => 'hubs h',
+        on         => 'p.id = h.id',
         inner_join => 'topics t',
         on         => 't.id = h.id',
         inner_join => 'hub_repos hr',
@@ -261,12 +223,14 @@ sub get_hub_repos {
             'h.id' => $hub,
         },
         union_all_select => [
-            'h.id', 't.uuid', 'h.name',
+            'h.id', 't.uuid', 'p.name',
             'hr.location', 'h.default_repo_id = hr.id AS is_default'
         ],
         from       => 'hub_repos hr2',
         inner_join => 'hubs h',
         on         => 'h.id = hr2.hub_id',
+        inner_join => 'projects p',
+        on         => 'p.id = h.id',
         inner_join => 'topics t',
         on         => 't.id = h.id',
         inner_join => 'hub_repos hr',
@@ -338,7 +302,7 @@ Bif::DB - helper methods for a read-only bif database
 
 =head1 VERSION
 
-0.1.4 (2014-10-27)
+0.1.5_1 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -385,26 +349,14 @@ or a hash reference containg the following keys:
 
 =back
 
-If the change relates to an issue then the following keys will also
-contain valid values:
-
-=over
-
-=item * project_issue_id - the project-specific topic ID
-
-=item * project_id - the project ID matching the project_issue_id
-
-=back
-
 =item get_local_hub_id -> Int
 
 Returns the ID for the local repository topic.
 
-=item get_projects( $PATH, [$HUB] ) -> [HashRef, ...]
+=item get_projects( $PATH ) -> @HashRefs | \@HashRefs
 
-Looks up the project(s) identified by C<$PATH> (and optionally C<$HUB>)
-returns undef, or a list of hash references containg the following
-keys:
+Looks up the project(s) identified by C<$PATH> (in [HUB/]PATH format)
+and returns a list of hash references containg the following keys:
 
 =over
 
@@ -430,6 +382,9 @@ keys:
 
 The list is sorted by hub name then by project path.
 
+NOTE: The underlying DBIx::ThinSQL method returns an Array References
+to the list in scalar context.
+
 =item status_ids( $project_id, $kind, @status ) -> \@ids, \@invalid
 
 Takes a project ID, a thread type (task, issue, etc) and a list of
@@ -478,7 +433,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Mark Lawrence <nomad@null.net>
+Copyright 2013-2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
