@@ -1,13 +1,13 @@
 package Bif::Sync;
 use strict;
 use warnings;
-use Bif::DB::Plugin::Changes;
+use Bif::DB::Plugin::ChangeUUIDv1;
 use Bif::Mo;
 use Coro;
 use Log::Any '$log';
 use JSON;
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 
 has changes_dup => (
     is      => 'rw',
@@ -128,12 +128,14 @@ sub real_send_changesets {
 
     $self->changes_tosend( $self->changes_tosend + $total );
 
-    my $sth = $self->db->xprepare_changeset_ext(@$statements);
+    my $db  = $self->db;
+    my $sth = $db->xprepare(@$statements);
     $sth->execute;
 
     my $sent = 0;
 
-    while ( my $changeset = $sth->changeset_ext ) {
+    while ( my $id = $sth->val ) {
+        my $changeset = $db->uchangeset_v1($id);
         return 'SendFailure' unless $self->write( 'CHANGESET', $changeset );
         $sent++;
         $self->changes_sent( $self->changes_sent + 1 );
@@ -186,6 +188,14 @@ sub recv_changesets {
     while ( $got < $total ) {
         my ( $action, $changeset ) = $self->read;
 
+        return "expected CHANGSET not: $action"
+          unless $action eq 'CHANGESET';
+
+        $self->changes_dup( $self->changes_dup + 1 )
+          unless $db->save_uchangeset_v1($changeset);
+
+=cut
+
         if ( !exists $import_functions{$action} ) {
             return "not implemented: $action";
         }
@@ -230,12 +240,9 @@ sub recv_changesets {
             );
 
             $i++;
-        }
 
-        $db->xdo(
-            insert_into => 'func_merge_changes',
-            values      => { merge => 1 },
-        );
+        }
+=cut
 
         $got++;
         $self->changes_recv( $self->changes_recv + 1 );
@@ -259,8 +266,9 @@ sub exchange_changesets {
     $self->write( 'TOTAL', $send_total );
 
     # Kick off receiving changesets as a separate Coro thread
+    my $fh   = select;
     my $coro = async {
-        select $App::bif::pager->fh if $App::bif::pager;
+        select $fh;
 
         $self->recv_changesets($changeset_functions);
     };
