@@ -5,7 +5,7 @@ use Coro;
 use DBIx::ThinSQL qw/qv sq/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 
 my %import_functions = (
     CHANGESET => {},
@@ -107,8 +107,9 @@ sub Bif::Sync::real_transfer_identity_changes {
     my $self = shift;
     my $tmp  = $self->temp_table;
 
+    my $fh   = select;
     my $send = async {
-        select $App::bif::pager->fh if $App::bif::pager;
+        select $fh;
 
         my $total = $self->db->xval(
             select => 'COALESCE(sum(t.ucount), 0)',
@@ -120,12 +121,13 @@ sub Bif::Sync::real_transfer_identity_changes {
 
         my $change_list = $self->db->xprepare(
             select => [
-                'c.id',                  'c.uuid',
-                'p.uuid AS parent_uuid', 't.uuid AS identity_uuid',
-                'c.mtime',               'c.mtimetz',
-                'c.author',              'c.email',
-                'c.lang',                'c.message',
-                'c.action',              'c.ucount',
+                'c.id',                    'c.uuid',
+                'p.uuid AS parent_uuid',   't.uuid AS identity_uuid',
+                'c.mtime',                 'c.mtimetz',
+                'c.author',                'c.author_contact',
+                'c.author_contact_method', 'c.author_shortname',
+                'c.lang',                  'c.message',
+                'c.action',                'c.ucount',
             ],
             from       => "$tmp tmp",
             inner_join => 'changes c',
@@ -148,6 +150,10 @@ sub Bif::Sync::real_transfer_identity_changes {
     my $r2 = $send->join;
 
     $self->db->xdo( delete_from => $tmp );
+    $self->db->xdo(
+        insert_into => 'func_merge_changes',
+        values      => { merge => 1 },
+    );
 
     if ( $r1 =~ m/^\d+$/ ) {
         $self->write( 'Recv', $r1 );
@@ -174,13 +180,10 @@ sub Bif::Sync::real_export_identity {
     my $recv = $self->send_changesets(
         $total,
         [
-            with => 'src',
-            as   => sq(
-                select   => 'eru.change_id AS id',
-                from     => 'entity_related_changes eru',
-                where    => { 'eru.entity_id' => $id },
-                order_by => 'eru.change_id ASC',
-            ),
+            select   => 'eru.change_id AS id',
+            from     => 'entity_related_changes eru',
+            where    => { 'eru.entity_id' => $id },
+            order_by => 'eru.change_id ASC',
         ]
     );
 
