@@ -4,7 +4,7 @@ use warnings;
 use DBIx::ThinSQL qw/qv sq/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 
 my $project_functions = {
     entity_contact_method_delta => 'func_import_entity_contact_method_delta',
@@ -132,17 +132,18 @@ sub Bif::Sync::real_transfer_project_related_changes {
     my $r = $self->exchange_changesets(
         $total,
         [
-            with => 'src',
-            as   => sq(
-                select   => 't.id AS id',
-                from     => "$tmp t",
-                order_by => 't.id ASC',
-            ),
+            select   => 't.id AS id',
+            from     => "$tmp t",
+            order_by => 't.id ASC',
         ],
         $project_functions,
     );
 
     $self->db->xdo( delete_from => $tmp );
+    $self->db->xdo(
+        insert_into => 'func_merge_changes',
+        values      => { merge => 1 },
+    );
 
     return $r unless $r eq 'ExchangeChangesets';
     return 'TransferProjectRelatedChanges';
@@ -161,13 +162,10 @@ sub Bif::Sync::real_export_project {
     my $recv = $self->send_changesets(
         $total,
         [
-            with => 'src',
-            as   => sq(
-                select   => 'pru.change_id AS id',
-                from     => 'project_related_changes pru',
-                where    => { 'pru.project_id' => $id },
-                order_by => 'pru.change_id ASC',
-            ),
+            select   => 'pru.change_id AS id',
+            from     => 'project_related_changes pru',
+            where    => { 'pru.project_id' => $id },
+            order_by => 'pru.change_id ASC',
         ]
     );
 
