@@ -9,7 +9,7 @@ use Coro::Handle;
 use DBIx::ThinSQL qw/sq/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5_1';
 extends 'Bif::Sync';
 
 has hub_id => ( is => 'rw', );
@@ -46,22 +46,18 @@ sub run {
     my $self = shift;
     $self->rh( Coro::Handle->new_from_fh( *STDIN, timeout => 30 ) );
     $self->wh( Coro::Handle->new_from_fh(*STDOUT) );
-
     $self->new_temp_table;
-    $self->db->begin_work;
 
     while (1) {
         my ( $action, $type, @rest ) = $self->read;
 
         if ( $action eq 'EOF' ) {
-            $self->db->rollback;
             return;
         }
         elsif ( $action eq 'INVALID' ) {
             next;
         }
         elsif ( $action eq 'QUIT' ) {
-            $self->db->commit;
             $self->write('Bye');
             return;
         }
@@ -86,13 +82,18 @@ sub run {
             next;
         }
 
-        my $response = eval { $self->$method(@rest) };
+        my $response = eval {
+            $self->db->txn(
+                sub {
+                    $self->$method(@rest);
+                }
+            );
+        };
 
         if ($@) {
             $log->error($@);
-            $self->write( 'InternalError', 'Internal Server Error',
+            $self->write( 'InternalServerError', 'Internal Server Error: ',
                 $action, $type, @rest );
-            $self->db->rollback;
             next;
         }
 
@@ -103,13 +104,11 @@ sub run {
             next;
         }
         elsif ( $response eq 'QUIT' ) {
-            $self->db->commit;
             $self->write('Bye');
             return;
         }
     }
 
-    $self->db->rollback;
     return;
 }
 
@@ -136,15 +135,24 @@ sub export_self {
 
 sub export_hub {
     my $self = shift;
+    my $name = shift;
     my $db   = $self->db;
-    my $id   = shift || $db->get_local_hub_id;
 
-    my $uuid = $db->xval(
-        select => 't.uuid',
-        from   => 'topics t',
-        where  => { 't.id' => $id },
+    my ( $id, $uuid ) = $db->xlist(
+        select     => [ 'h.id', 't.uuid' ],
+        from       => 'projects p',
+        inner_join => 'hubs h',
+        on         => 'h.id = p.id',
+        inner_join => 'topics t',
+        on         => 't.id = h.id',
+        where => { 'p.name' => $name },
     );
 
+    if ( !$uuid ) {
+        $self->write( 'HubNotFound', 'hub not found: ' . $name );
+        return 'HubNotFound';
+    }
+
     $self->write( 'EXPORT', 'hub', $uuid );
     return $self->real_export_hub($id);
 }
