@@ -7,6 +7,8 @@ use Exporter::Tidy default => [
       run_in_tempdir
       bif
       bif2
+      hub
+      hub2
       bifsync
       bifcheck
       debug_on
@@ -42,7 +44,8 @@ $ENV{PATH} = $SRC_DIR->child('tbin') . ':' . $ENV{PATH};
 
 sub run_in_tempdir (&) {
     my $sub = shift;
-    my $tmp = Path::Tiny->tempdir( CLEANUP => 1 );
+    my $tmp = Path::Tiny->tempdir( DIR => $ENV{TMPDIR}, CLEANUP => 1 );
+    Test::More::diag("\n$tmp");
 
     {
         $log->debug("cd $tmp");
@@ -55,7 +58,7 @@ sub run_in_tempdir (&) {
 }
 
 sub bif {
-    my @bif = ( @_, qw/ --no-pager / );
+    my @bif = @_;
 
     my $stdout;
     my $junk;
@@ -65,10 +68,11 @@ sub bif {
         open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
     }
 
-    Test::More::diag("@bif") if $VERBOSE;
+    Test::More::diag("bif @bif");
+
     my $result = eval {
         my ( $class, $opts ) = class_optargs( 'App::bif', @bif );
-        $class->new( opts => $opts )->run;
+        $class->new( opts => $opts, no_pager => 1 )->run;
     };
     my $err = $@;
 
@@ -90,6 +94,16 @@ sub bif2 {
     return bif(@_);
 }
 
+sub hub {
+    local $CWD = 'hub.bif';
+    return bif(@_);
+}
+
+sub hub2 {
+    local $CWD = 'hub2.bif';
+    return bif(@_);
+}
+
 sub bifsync {
     my $stdout;
     my $junk;
@@ -99,7 +113,8 @@ sub bifsync {
         open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
     }
 
-    Test::More::diag("@_") if $VERBOSE;
+    Test::More::diag("bifsync @_");
+
     my $result = eval {
         my ( $class, $opts ) = class_optargs( 'App::bifsync', @_ );
         $class->new( opts => $opts )->run;
@@ -123,19 +138,6 @@ sub bifcheck {
     Test::More::diag $@ if $@;
 }
 
-my $DEBUG;
-
-sub debug_on {
-    return if $DEBUG;
-    $DEBUG = Log::Any::Adapter->set('Diag');
-}
-
-sub debug_off {
-    return unless $DEBUG;
-    Log::Any::Adapter->remove($DEBUG);
-    $DEBUG = undef;
-}
-
 my $change = 0;
 
 sub new_test_change {
@@ -191,7 +193,6 @@ sub new_test_hub {
         values      => $ref,
     );
 
-    debug_on;
     $db->xdo(
         insert_into => 'func_new_hub_repo',
         values      => {
